"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.connections_and_sockets.gears._2559 import (
        AGMAGleasonConicalGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2560 import (
        AGMAGleasonConicalGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2561 import (
        BevelDifferentialGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2562 import (
        BevelDifferentialGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2563 import (
        BevelGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2564 import (
        BevelGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2565 import (
        ConceptGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2566 import (
        ConceptGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2567 import (
        ConicalGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2568 import (
        ConicalGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2569 import (
        CylindricalGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2570 import (
        CylindricalGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2571 import (
        FaceGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2572 import (
        FaceGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2573 import (
        GearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2574 import (
        GearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2575 import (
        HypoidGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2576 import (
        HypoidGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2577 import (
        KlingelnbergConicalGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2578 import (
        KlingelnbergCycloPalloidConicalGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2579 import (
        KlingelnbergCycloPalloidHypoidGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2580 import (
        KlingelnbergCycloPalloidSpiralBevelGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2581 import (
        KlingelnbergHypoidGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2582 import (
        KlingelnbergSpiralBevelGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2583 import (
        SpiralBevelGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2584 import (
        SpiralBevelGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2585 import (
        StraightBevelDiffGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2586 import (
        StraightBevelDiffGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2587 import (
        StraightBevelGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2588 import (
        StraightBevelGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2589 import (
        WormGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2590 import (
        WormGearTeethSocket,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2591 import (
        ZerolBevelGearMesh,
    )
    from mastapy._private.system_model.connections_and_sockets.gears._2592 import (
        ZerolBevelGearTeethSocket,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.connections_and_sockets.gears._2559": [
            "AGMAGleasonConicalGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2560": [
            "AGMAGleasonConicalGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2561": [
            "BevelDifferentialGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2562": [
            "BevelDifferentialGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2563": ["BevelGearMesh"],
        "_private.system_model.connections_and_sockets.gears._2564": [
            "BevelGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2565": [
            "ConceptGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2566": [
            "ConceptGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2567": [
            "ConicalGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2568": [
            "ConicalGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2569": [
            "CylindricalGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2570": [
            "CylindricalGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2571": ["FaceGearMesh"],
        "_private.system_model.connections_and_sockets.gears._2572": [
            "FaceGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2573": ["GearMesh"],
        "_private.system_model.connections_and_sockets.gears._2574": [
            "GearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2575": ["HypoidGearMesh"],
        "_private.system_model.connections_and_sockets.gears._2576": [
            "HypoidGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2577": [
            "KlingelnbergConicalGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2578": [
            "KlingelnbergCycloPalloidConicalGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2579": [
            "KlingelnbergCycloPalloidHypoidGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2580": [
            "KlingelnbergCycloPalloidSpiralBevelGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2581": [
            "KlingelnbergHypoidGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2582": [
            "KlingelnbergSpiralBevelGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2583": [
            "SpiralBevelGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2584": [
            "SpiralBevelGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2585": [
            "StraightBevelDiffGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2586": [
            "StraightBevelDiffGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2587": [
            "StraightBevelGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2588": [
            "StraightBevelGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2589": ["WormGearMesh"],
        "_private.system_model.connections_and_sockets.gears._2590": [
            "WormGearTeethSocket"
        ],
        "_private.system_model.connections_and_sockets.gears._2591": [
            "ZerolBevelGearMesh"
        ],
        "_private.system_model.connections_and_sockets.gears._2592": [
            "ZerolBevelGearTeethSocket"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AGMAGleasonConicalGearMesh",
    "AGMAGleasonConicalGearTeethSocket",
    "BevelDifferentialGearMesh",
    "BevelDifferentialGearTeethSocket",
    "BevelGearMesh",
    "BevelGearTeethSocket",
    "ConceptGearMesh",
    "ConceptGearTeethSocket",
    "ConicalGearMesh",
    "ConicalGearTeethSocket",
    "CylindricalGearMesh",
    "CylindricalGearTeethSocket",
    "FaceGearMesh",
    "FaceGearTeethSocket",
    "GearMesh",
    "GearTeethSocket",
    "HypoidGearMesh",
    "HypoidGearTeethSocket",
    "KlingelnbergConicalGearTeethSocket",
    "KlingelnbergCycloPalloidConicalGearMesh",
    "KlingelnbergCycloPalloidHypoidGearMesh",
    "KlingelnbergCycloPalloidSpiralBevelGearMesh",
    "KlingelnbergHypoidGearTeethSocket",
    "KlingelnbergSpiralBevelGearTeethSocket",
    "SpiralBevelGearMesh",
    "SpiralBevelGearTeethSocket",
    "StraightBevelDiffGearMesh",
    "StraightBevelDiffGearTeethSocket",
    "StraightBevelGearMesh",
    "StraightBevelGearTeethSocket",
    "WormGearMesh",
    "WormGearTeethSocket",
    "ZerolBevelGearMesh",
    "ZerolBevelGearTeethSocket",
)
