"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7584 import (
        AbstractAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7585 import (
        AbstractShaftCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7586 import (
        AbstractShaftOrHousingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7587 import (
        AbstractShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7588 import (
        AGMAGleasonConicalGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7589 import (
        AGMAGleasonConicalGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7590 import (
        AGMAGleasonConicalGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7591 import (
        AssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7592 import (
        BearingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7593 import (
        BeltConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7594 import (
        BeltDriveCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7595 import (
        BevelDifferentialGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7596 import (
        BevelDifferentialGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7597 import (
        BevelDifferentialGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7598 import (
        BevelDifferentialPlanetGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7599 import (
        BevelDifferentialSunGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7600 import (
        BevelGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7601 import (
        BevelGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7602 import (
        BevelGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7603 import (
        BoltCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7604 import (
        BoltedJointCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7605 import (
        ClutchCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7606 import (
        ClutchConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7607 import (
        ClutchHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7608 import (
        CoaxialConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7609 import (
        ComponentCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7610 import (
        ConceptCouplingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7611 import (
        ConceptCouplingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7612 import (
        ConceptCouplingHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7613 import (
        ConceptGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7614 import (
        ConceptGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7615 import (
        ConceptGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7616 import (
        ConicalGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7617 import (
        ConicalGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7618 import (
        ConicalGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7619 import (
        ConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7620 import (
        ConnectorCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7621 import (
        CouplingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7622 import (
        CouplingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7623 import (
        CouplingHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7624 import (
        CVTBeltConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7625 import (
        CVTCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7626 import (
        CVTPulleyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7627 import (
        CycloidalAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7628 import (
        CycloidalDiscCentralBearingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7629 import (
        CycloidalDiscCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7630 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7631 import (
        CylindricalGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7632 import (
        CylindricalGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7633 import (
        CylindricalGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7634 import (
        CylindricalPlanetGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7635 import (
        DatumCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7636 import (
        ExternalCADModelCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7637 import (
        FaceGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7638 import (
        FaceGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7639 import (
        FaceGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7640 import (
        FEPartCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7641 import (
        FlexiblePinAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7642 import (
        GearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7643 import (
        GearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7644 import (
        GearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7645 import (
        GuideDxfModelCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7646 import (
        HypoidGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7647 import (
        HypoidGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7648 import (
        HypoidGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7649 import (
        InterMountableComponentConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7650 import (
        KlingelnbergCycloPalloidConicalGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7651 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7652 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7653 import (
        KlingelnbergCycloPalloidHypoidGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7654 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7655 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7656 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7657 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7658 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7659 import (
        MassDiscCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7660 import (
        MeasurementComponentCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7661 import (
        MicrophoneArrayCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7662 import (
        MicrophoneCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7663 import (
        MountableComponentCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7664 import (
        OilSealCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7665 import (
        PartCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7666 import (
        PartToPartShearCouplingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7667 import (
        PartToPartShearCouplingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7668 import (
        PartToPartShearCouplingHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7669 import (
        PlanetaryConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7670 import (
        PlanetaryGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7671 import (
        PlanetCarrierCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7672 import (
        PointLoadCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7673 import (
        PowerLoadCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7674 import (
        PulleyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7675 import (
        RingPinsCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7676 import (
        RingPinsToDiscConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7677 import (
        RollingRingAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7678 import (
        RollingRingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7679 import (
        RollingRingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7680 import (
        RootAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7681 import (
        ShaftCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7682 import (
        ShaftHubConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7683 import (
        ShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7684 import (
        SpecialisedAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7685 import (
        SpiralBevelGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7686 import (
        SpiralBevelGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7687 import (
        SpiralBevelGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7688 import (
        SpringDamperCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7689 import (
        SpringDamperConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7690 import (
        SpringDamperHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7691 import (
        StraightBevelDiffGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7692 import (
        StraightBevelDiffGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7693 import (
        StraightBevelDiffGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7694 import (
        StraightBevelGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7695 import (
        StraightBevelGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7696 import (
        StraightBevelGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7697 import (
        StraightBevelPlanetGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7698 import (
        StraightBevelSunGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7699 import (
        SynchroniserCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7700 import (
        SynchroniserHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7701 import (
        SynchroniserPartCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7702 import (
        SynchroniserSleeveCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7703 import (
        TorqueConverterCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7704 import (
        TorqueConverterConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7705 import (
        TorqueConverterPumpCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7706 import (
        TorqueConverterTurbineCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7707 import (
        UnbalancedMassCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7708 import (
        VirtualComponentCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7709 import (
        WormGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7710 import (
        WormGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7711 import (
        WormGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7712 import (
        ZerolBevelGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7713 import (
        ZerolBevelGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7714 import (
        ZerolBevelGearSetCompoundAdvancedSystemDeflection,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7584": [
            "AbstractAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7585": [
            "AbstractShaftCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7586": [
            "AbstractShaftOrHousingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7587": [
            "AbstractShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7588": [
            "AGMAGleasonConicalGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7589": [
            "AGMAGleasonConicalGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7590": [
            "AGMAGleasonConicalGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7591": [
            "AssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7592": [
            "BearingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7593": [
            "BeltConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7594": [
            "BeltDriveCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7595": [
            "BevelDifferentialGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7596": [
            "BevelDifferentialGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7597": [
            "BevelDifferentialGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7598": [
            "BevelDifferentialPlanetGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7599": [
            "BevelDifferentialSunGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7600": [
            "BevelGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7601": [
            "BevelGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7602": [
            "BevelGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7603": [
            "BoltCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7604": [
            "BoltedJointCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7605": [
            "ClutchCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7606": [
            "ClutchConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7607": [
            "ClutchHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7608": [
            "CoaxialConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7609": [
            "ComponentCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7610": [
            "ConceptCouplingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7611": [
            "ConceptCouplingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7612": [
            "ConceptCouplingHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7613": [
            "ConceptGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7614": [
            "ConceptGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7615": [
            "ConceptGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7616": [
            "ConicalGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7617": [
            "ConicalGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7618": [
            "ConicalGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7619": [
            "ConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7620": [
            "ConnectorCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7621": [
            "CouplingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7622": [
            "CouplingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7623": [
            "CouplingHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7624": [
            "CVTBeltConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7625": [
            "CVTCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7626": [
            "CVTPulleyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7627": [
            "CycloidalAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7628": [
            "CycloidalDiscCentralBearingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7629": [
            "CycloidalDiscCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7630": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7631": [
            "CylindricalGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7632": [
            "CylindricalGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7633": [
            "CylindricalGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7634": [
            "CylindricalPlanetGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7635": [
            "DatumCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7636": [
            "ExternalCADModelCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7637": [
            "FaceGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7638": [
            "FaceGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7639": [
            "FaceGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7640": [
            "FEPartCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7641": [
            "FlexiblePinAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7642": [
            "GearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7643": [
            "GearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7644": [
            "GearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7645": [
            "GuideDxfModelCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7646": [
            "HypoidGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7647": [
            "HypoidGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7648": [
            "HypoidGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7649": [
            "InterMountableComponentConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7650": [
            "KlingelnbergCycloPalloidConicalGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7651": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7652": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7653": [
            "KlingelnbergCycloPalloidHypoidGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7654": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7655": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7656": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7657": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7658": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7659": [
            "MassDiscCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7660": [
            "MeasurementComponentCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7661": [
            "MicrophoneArrayCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7662": [
            "MicrophoneCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7663": [
            "MountableComponentCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7664": [
            "OilSealCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7665": [
            "PartCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7666": [
            "PartToPartShearCouplingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7667": [
            "PartToPartShearCouplingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7668": [
            "PartToPartShearCouplingHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7669": [
            "PlanetaryConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7670": [
            "PlanetaryGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7671": [
            "PlanetCarrierCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7672": [
            "PointLoadCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7673": [
            "PowerLoadCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7674": [
            "PulleyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7675": [
            "RingPinsCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7676": [
            "RingPinsToDiscConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7677": [
            "RollingRingAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7678": [
            "RollingRingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7679": [
            "RollingRingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7680": [
            "RootAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7681": [
            "ShaftCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7682": [
            "ShaftHubConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7683": [
            "ShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7684": [
            "SpecialisedAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7685": [
            "SpiralBevelGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7686": [
            "SpiralBevelGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7687": [
            "SpiralBevelGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7688": [
            "SpringDamperCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7689": [
            "SpringDamperConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7690": [
            "SpringDamperHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7691": [
            "StraightBevelDiffGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7692": [
            "StraightBevelDiffGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7693": [
            "StraightBevelDiffGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7694": [
            "StraightBevelGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7695": [
            "StraightBevelGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7696": [
            "StraightBevelGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7697": [
            "StraightBevelPlanetGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7698": [
            "StraightBevelSunGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7699": [
            "SynchroniserCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7700": [
            "SynchroniserHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7701": [
            "SynchroniserPartCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7702": [
            "SynchroniserSleeveCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7703": [
            "TorqueConverterCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7704": [
            "TorqueConverterConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7705": [
            "TorqueConverterPumpCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7706": [
            "TorqueConverterTurbineCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7707": [
            "UnbalancedMassCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7708": [
            "VirtualComponentCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7709": [
            "WormGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7710": [
            "WormGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7711": [
            "WormGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7712": [
            "ZerolBevelGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7713": [
            "ZerolBevelGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7714": [
            "ZerolBevelGearSetCompoundAdvancedSystemDeflection"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundAdvancedSystemDeflection",
    "AbstractShaftCompoundAdvancedSystemDeflection",
    "AbstractShaftOrHousingCompoundAdvancedSystemDeflection",
    "AbstractShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection",
    "AGMAGleasonConicalGearCompoundAdvancedSystemDeflection",
    "AGMAGleasonConicalGearMeshCompoundAdvancedSystemDeflection",
    "AGMAGleasonConicalGearSetCompoundAdvancedSystemDeflection",
    "AssemblyCompoundAdvancedSystemDeflection",
    "BearingCompoundAdvancedSystemDeflection",
    "BeltConnectionCompoundAdvancedSystemDeflection",
    "BeltDriveCompoundAdvancedSystemDeflection",
    "BevelDifferentialGearCompoundAdvancedSystemDeflection",
    "BevelDifferentialGearMeshCompoundAdvancedSystemDeflection",
    "BevelDifferentialGearSetCompoundAdvancedSystemDeflection",
    "BevelDifferentialPlanetGearCompoundAdvancedSystemDeflection",
    "BevelDifferentialSunGearCompoundAdvancedSystemDeflection",
    "BevelGearCompoundAdvancedSystemDeflection",
    "BevelGearMeshCompoundAdvancedSystemDeflection",
    "BevelGearSetCompoundAdvancedSystemDeflection",
    "BoltCompoundAdvancedSystemDeflection",
    "BoltedJointCompoundAdvancedSystemDeflection",
    "ClutchCompoundAdvancedSystemDeflection",
    "ClutchConnectionCompoundAdvancedSystemDeflection",
    "ClutchHalfCompoundAdvancedSystemDeflection",
    "CoaxialConnectionCompoundAdvancedSystemDeflection",
    "ComponentCompoundAdvancedSystemDeflection",
    "ConceptCouplingCompoundAdvancedSystemDeflection",
    "ConceptCouplingConnectionCompoundAdvancedSystemDeflection",
    "ConceptCouplingHalfCompoundAdvancedSystemDeflection",
    "ConceptGearCompoundAdvancedSystemDeflection",
    "ConceptGearMeshCompoundAdvancedSystemDeflection",
    "ConceptGearSetCompoundAdvancedSystemDeflection",
    "ConicalGearCompoundAdvancedSystemDeflection",
    "ConicalGearMeshCompoundAdvancedSystemDeflection",
    "ConicalGearSetCompoundAdvancedSystemDeflection",
    "ConnectionCompoundAdvancedSystemDeflection",
    "ConnectorCompoundAdvancedSystemDeflection",
    "CouplingCompoundAdvancedSystemDeflection",
    "CouplingConnectionCompoundAdvancedSystemDeflection",
    "CouplingHalfCompoundAdvancedSystemDeflection",
    "CVTBeltConnectionCompoundAdvancedSystemDeflection",
    "CVTCompoundAdvancedSystemDeflection",
    "CVTPulleyCompoundAdvancedSystemDeflection",
    "CycloidalAssemblyCompoundAdvancedSystemDeflection",
    "CycloidalDiscCentralBearingConnectionCompoundAdvancedSystemDeflection",
    "CycloidalDiscCompoundAdvancedSystemDeflection",
    "CycloidalDiscPlanetaryBearingConnectionCompoundAdvancedSystemDeflection",
    "CylindricalGearCompoundAdvancedSystemDeflection",
    "CylindricalGearMeshCompoundAdvancedSystemDeflection",
    "CylindricalGearSetCompoundAdvancedSystemDeflection",
    "CylindricalPlanetGearCompoundAdvancedSystemDeflection",
    "DatumCompoundAdvancedSystemDeflection",
    "ExternalCADModelCompoundAdvancedSystemDeflection",
    "FaceGearCompoundAdvancedSystemDeflection",
    "FaceGearMeshCompoundAdvancedSystemDeflection",
    "FaceGearSetCompoundAdvancedSystemDeflection",
    "FEPartCompoundAdvancedSystemDeflection",
    "FlexiblePinAssemblyCompoundAdvancedSystemDeflection",
    "GearCompoundAdvancedSystemDeflection",
    "GearMeshCompoundAdvancedSystemDeflection",
    "GearSetCompoundAdvancedSystemDeflection",
    "GuideDxfModelCompoundAdvancedSystemDeflection",
    "HypoidGearCompoundAdvancedSystemDeflection",
    "HypoidGearMeshCompoundAdvancedSystemDeflection",
    "HypoidGearSetCompoundAdvancedSystemDeflection",
    "InterMountableComponentConnectionCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearSetCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection",
    "MassDiscCompoundAdvancedSystemDeflection",
    "MeasurementComponentCompoundAdvancedSystemDeflection",
    "MicrophoneArrayCompoundAdvancedSystemDeflection",
    "MicrophoneCompoundAdvancedSystemDeflection",
    "MountableComponentCompoundAdvancedSystemDeflection",
    "OilSealCompoundAdvancedSystemDeflection",
    "PartCompoundAdvancedSystemDeflection",
    "PartToPartShearCouplingCompoundAdvancedSystemDeflection",
    "PartToPartShearCouplingConnectionCompoundAdvancedSystemDeflection",
    "PartToPartShearCouplingHalfCompoundAdvancedSystemDeflection",
    "PlanetaryConnectionCompoundAdvancedSystemDeflection",
    "PlanetaryGearSetCompoundAdvancedSystemDeflection",
    "PlanetCarrierCompoundAdvancedSystemDeflection",
    "PointLoadCompoundAdvancedSystemDeflection",
    "PowerLoadCompoundAdvancedSystemDeflection",
    "PulleyCompoundAdvancedSystemDeflection",
    "RingPinsCompoundAdvancedSystemDeflection",
    "RingPinsToDiscConnectionCompoundAdvancedSystemDeflection",
    "RollingRingAssemblyCompoundAdvancedSystemDeflection",
    "RollingRingCompoundAdvancedSystemDeflection",
    "RollingRingConnectionCompoundAdvancedSystemDeflection",
    "RootAssemblyCompoundAdvancedSystemDeflection",
    "ShaftCompoundAdvancedSystemDeflection",
    "ShaftHubConnectionCompoundAdvancedSystemDeflection",
    "ShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection",
    "SpecialisedAssemblyCompoundAdvancedSystemDeflection",
    "SpiralBevelGearCompoundAdvancedSystemDeflection",
    "SpiralBevelGearMeshCompoundAdvancedSystemDeflection",
    "SpiralBevelGearSetCompoundAdvancedSystemDeflection",
    "SpringDamperCompoundAdvancedSystemDeflection",
    "SpringDamperConnectionCompoundAdvancedSystemDeflection",
    "SpringDamperHalfCompoundAdvancedSystemDeflection",
    "StraightBevelDiffGearCompoundAdvancedSystemDeflection",
    "StraightBevelDiffGearMeshCompoundAdvancedSystemDeflection",
    "StraightBevelDiffGearSetCompoundAdvancedSystemDeflection",
    "StraightBevelGearCompoundAdvancedSystemDeflection",
    "StraightBevelGearMeshCompoundAdvancedSystemDeflection",
    "StraightBevelGearSetCompoundAdvancedSystemDeflection",
    "StraightBevelPlanetGearCompoundAdvancedSystemDeflection",
    "StraightBevelSunGearCompoundAdvancedSystemDeflection",
    "SynchroniserCompoundAdvancedSystemDeflection",
    "SynchroniserHalfCompoundAdvancedSystemDeflection",
    "SynchroniserPartCompoundAdvancedSystemDeflection",
    "SynchroniserSleeveCompoundAdvancedSystemDeflection",
    "TorqueConverterCompoundAdvancedSystemDeflection",
    "TorqueConverterConnectionCompoundAdvancedSystemDeflection",
    "TorqueConverterPumpCompoundAdvancedSystemDeflection",
    "TorqueConverterTurbineCompoundAdvancedSystemDeflection",
    "UnbalancedMassCompoundAdvancedSystemDeflection",
    "VirtualComponentCompoundAdvancedSystemDeflection",
    "WormGearCompoundAdvancedSystemDeflection",
    "WormGearMeshCompoundAdvancedSystemDeflection",
    "WormGearSetCompoundAdvancedSystemDeflection",
    "ZerolBevelGearCompoundAdvancedSystemDeflection",
    "ZerolBevelGearMeshCompoundAdvancedSystemDeflection",
    "ZerolBevelGearSetCompoundAdvancedSystemDeflection",
)
