"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6239 import (
        AbstractAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6240 import (
        AbstractShaftCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6241 import (
        AbstractShaftOrHousingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6242 import (
        AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6243 import (
        AGMAGleasonConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6244 import (
        AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6245 import (
        AGMAGleasonConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6246 import (
        AssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6247 import (
        BearingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6248 import (
        BeltConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6249 import (
        BeltDriveCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6250 import (
        BevelDifferentialGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6251 import (
        BevelDifferentialGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6252 import (
        BevelDifferentialGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6253 import (
        BevelDifferentialPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6254 import (
        BevelDifferentialSunGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6255 import (
        BevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6256 import (
        BevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6257 import (
        BevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6258 import (
        BoltCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6259 import (
        BoltedJointCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6260 import (
        ClutchCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6261 import (
        ClutchConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6262 import (
        ClutchHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6263 import (
        CoaxialConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6264 import (
        ComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6265 import (
        ConceptCouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6266 import (
        ConceptCouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6267 import (
        ConceptCouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6268 import (
        ConceptGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6269 import (
        ConceptGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6270 import (
        ConceptGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6271 import (
        ConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6272 import (
        ConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6273 import (
        ConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6274 import (
        ConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6275 import (
        ConnectorCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6276 import (
        CouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6277 import (
        CouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6278 import (
        CouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6279 import (
        CVTBeltConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6280 import (
        CVTCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6281 import (
        CVTPulleyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6282 import (
        CycloidalAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6283 import (
        CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6284 import (
        CycloidalDiscCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6285 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6286 import (
        CylindricalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6287 import (
        CylindricalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6288 import (
        CylindricalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6289 import (
        CylindricalPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6290 import (
        DatumCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6291 import (
        ExternalCADModelCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6292 import (
        FaceGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6293 import (
        FaceGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6294 import (
        FaceGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6295 import (
        FEPartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6296 import (
        FlexiblePinAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6297 import (
        GearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6298 import (
        GearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6299 import (
        GearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6300 import (
        GuideDxfModelCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6301 import (
        HypoidGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6302 import (
        HypoidGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6303 import (
        HypoidGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6304 import (
        InterMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6305 import (
        KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6306 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6307 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6308 import (
        KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6309 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6310 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6311 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6312 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6313 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6314 import (
        MassDiscCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6315 import (
        MeasurementComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6316 import (
        MicrophoneArrayCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6317 import (
        MicrophoneCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6318 import (
        MountableComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6319 import (
        OilSealCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6320 import (
        PartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6321 import (
        PartToPartShearCouplingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6322 import (
        PartToPartShearCouplingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6323 import (
        PartToPartShearCouplingHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6324 import (
        PlanetaryConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6325 import (
        PlanetaryGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6326 import (
        PlanetCarrierCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6327 import (
        PointLoadCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6328 import (
        PowerLoadCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6329 import (
        PulleyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6330 import (
        RingPinsCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6331 import (
        RingPinsToDiscConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6332 import (
        RollingRingAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6333 import (
        RollingRingCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6334 import (
        RollingRingConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6335 import (
        RootAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6336 import (
        ShaftCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6337 import (
        ShaftHubConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6338 import (
        ShaftToMountableComponentConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6339 import (
        SpecialisedAssemblyCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6340 import (
        SpiralBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6341 import (
        SpiralBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6342 import (
        SpiralBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6343 import (
        SpringDamperCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6344 import (
        SpringDamperConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6345 import (
        SpringDamperHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6346 import (
        StraightBevelDiffGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6347 import (
        StraightBevelDiffGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6348 import (
        StraightBevelDiffGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6349 import (
        StraightBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6350 import (
        StraightBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6351 import (
        StraightBevelGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6352 import (
        StraightBevelPlanetGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6353 import (
        StraightBevelSunGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6354 import (
        SynchroniserCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6355 import (
        SynchroniserHalfCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6356 import (
        SynchroniserPartCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6357 import (
        SynchroniserSleeveCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6358 import (
        TorqueConverterCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6359 import (
        TorqueConverterConnectionCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6360 import (
        TorqueConverterPumpCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6361 import (
        TorqueConverterTurbineCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6362 import (
        UnbalancedMassCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6363 import (
        VirtualComponentCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6364 import (
        WormGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6365 import (
        WormGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6366 import (
        WormGearSetCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6367 import (
        ZerolBevelGearCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6368 import (
        ZerolBevelGearMeshCompoundHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound._6369 import (
        ZerolBevelGearSetCompoundHarmonicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6239": [
            "AbstractAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6240": [
            "AbstractShaftCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6241": [
            "AbstractShaftOrHousingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6242": [
            "AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6243": [
            "AGMAGleasonConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6244": [
            "AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6245": [
            "AGMAGleasonConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6246": [
            "AssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6247": [
            "BearingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6248": [
            "BeltConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6249": [
            "BeltDriveCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6250": [
            "BevelDifferentialGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6251": [
            "BevelDifferentialGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6252": [
            "BevelDifferentialGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6253": [
            "BevelDifferentialPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6254": [
            "BevelDifferentialSunGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6255": [
            "BevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6256": [
            "BevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6257": [
            "BevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6258": [
            "BoltCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6259": [
            "BoltedJointCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6260": [
            "ClutchCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6261": [
            "ClutchConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6262": [
            "ClutchHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6263": [
            "CoaxialConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6264": [
            "ComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6265": [
            "ConceptCouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6266": [
            "ConceptCouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6267": [
            "ConceptCouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6268": [
            "ConceptGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6269": [
            "ConceptGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6270": [
            "ConceptGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6271": [
            "ConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6272": [
            "ConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6273": [
            "ConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6274": [
            "ConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6275": [
            "ConnectorCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6276": [
            "CouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6277": [
            "CouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6278": [
            "CouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6279": [
            "CVTBeltConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6280": [
            "CVTCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6281": [
            "CVTPulleyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6282": [
            "CycloidalAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6283": [
            "CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6284": [
            "CycloidalDiscCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6285": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6286": [
            "CylindricalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6287": [
            "CylindricalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6288": [
            "CylindricalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6289": [
            "CylindricalPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6290": [
            "DatumCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6291": [
            "ExternalCADModelCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6292": [
            "FaceGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6293": [
            "FaceGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6294": [
            "FaceGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6295": [
            "FEPartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6296": [
            "FlexiblePinAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6297": [
            "GearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6298": [
            "GearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6299": [
            "GearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6300": [
            "GuideDxfModelCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6301": [
            "HypoidGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6302": [
            "HypoidGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6303": [
            "HypoidGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6304": [
            "InterMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6305": [
            "KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6306": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6307": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6308": [
            "KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6309": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6310": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6311": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6312": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6313": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6314": [
            "MassDiscCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6315": [
            "MeasurementComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6316": [
            "MicrophoneArrayCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6317": [
            "MicrophoneCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6318": [
            "MountableComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6319": [
            "OilSealCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6320": [
            "PartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6321": [
            "PartToPartShearCouplingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6322": [
            "PartToPartShearCouplingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6323": [
            "PartToPartShearCouplingHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6324": [
            "PlanetaryConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6325": [
            "PlanetaryGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6326": [
            "PlanetCarrierCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6327": [
            "PointLoadCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6328": [
            "PowerLoadCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6329": [
            "PulleyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6330": [
            "RingPinsCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6331": [
            "RingPinsToDiscConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6332": [
            "RollingRingAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6333": [
            "RollingRingCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6334": [
            "RollingRingConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6335": [
            "RootAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6336": [
            "ShaftCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6337": [
            "ShaftHubConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6338": [
            "ShaftToMountableComponentConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6339": [
            "SpecialisedAssemblyCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6340": [
            "SpiralBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6341": [
            "SpiralBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6342": [
            "SpiralBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6343": [
            "SpringDamperCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6344": [
            "SpringDamperConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6345": [
            "SpringDamperHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6346": [
            "StraightBevelDiffGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6347": [
            "StraightBevelDiffGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6348": [
            "StraightBevelDiffGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6349": [
            "StraightBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6350": [
            "StraightBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6351": [
            "StraightBevelGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6352": [
            "StraightBevelPlanetGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6353": [
            "StraightBevelSunGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6354": [
            "SynchroniserCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6355": [
            "SynchroniserHalfCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6356": [
            "SynchroniserPartCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6357": [
            "SynchroniserSleeveCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6358": [
            "TorqueConverterCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6359": [
            "TorqueConverterConnectionCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6360": [
            "TorqueConverterPumpCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6361": [
            "TorqueConverterTurbineCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6362": [
            "UnbalancedMassCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6363": [
            "VirtualComponentCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6364": [
            "WormGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6365": [
            "WormGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6366": [
            "WormGearSetCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6367": [
            "ZerolBevelGearCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6368": [
            "ZerolBevelGearMeshCompoundHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses.compound._6369": [
            "ZerolBevelGearSetCompoundHarmonicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundHarmonicAnalysis",
    "AbstractShaftCompoundHarmonicAnalysis",
    "AbstractShaftOrHousingCompoundHarmonicAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearMeshCompoundHarmonicAnalysis",
    "AGMAGleasonConicalGearSetCompoundHarmonicAnalysis",
    "AssemblyCompoundHarmonicAnalysis",
    "BearingCompoundHarmonicAnalysis",
    "BeltConnectionCompoundHarmonicAnalysis",
    "BeltDriveCompoundHarmonicAnalysis",
    "BevelDifferentialGearCompoundHarmonicAnalysis",
    "BevelDifferentialGearMeshCompoundHarmonicAnalysis",
    "BevelDifferentialGearSetCompoundHarmonicAnalysis",
    "BevelDifferentialPlanetGearCompoundHarmonicAnalysis",
    "BevelDifferentialSunGearCompoundHarmonicAnalysis",
    "BevelGearCompoundHarmonicAnalysis",
    "BevelGearMeshCompoundHarmonicAnalysis",
    "BevelGearSetCompoundHarmonicAnalysis",
    "BoltCompoundHarmonicAnalysis",
    "BoltedJointCompoundHarmonicAnalysis",
    "ClutchCompoundHarmonicAnalysis",
    "ClutchConnectionCompoundHarmonicAnalysis",
    "ClutchHalfCompoundHarmonicAnalysis",
    "CoaxialConnectionCompoundHarmonicAnalysis",
    "ComponentCompoundHarmonicAnalysis",
    "ConceptCouplingCompoundHarmonicAnalysis",
    "ConceptCouplingConnectionCompoundHarmonicAnalysis",
    "ConceptCouplingHalfCompoundHarmonicAnalysis",
    "ConceptGearCompoundHarmonicAnalysis",
    "ConceptGearMeshCompoundHarmonicAnalysis",
    "ConceptGearSetCompoundHarmonicAnalysis",
    "ConicalGearCompoundHarmonicAnalysis",
    "ConicalGearMeshCompoundHarmonicAnalysis",
    "ConicalGearSetCompoundHarmonicAnalysis",
    "ConnectionCompoundHarmonicAnalysis",
    "ConnectorCompoundHarmonicAnalysis",
    "CouplingCompoundHarmonicAnalysis",
    "CouplingConnectionCompoundHarmonicAnalysis",
    "CouplingHalfCompoundHarmonicAnalysis",
    "CVTBeltConnectionCompoundHarmonicAnalysis",
    "CVTCompoundHarmonicAnalysis",
    "CVTPulleyCompoundHarmonicAnalysis",
    "CycloidalAssemblyCompoundHarmonicAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundHarmonicAnalysis",
    "CycloidalDiscCompoundHarmonicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundHarmonicAnalysis",
    "CylindricalGearCompoundHarmonicAnalysis",
    "CylindricalGearMeshCompoundHarmonicAnalysis",
    "CylindricalGearSetCompoundHarmonicAnalysis",
    "CylindricalPlanetGearCompoundHarmonicAnalysis",
    "DatumCompoundHarmonicAnalysis",
    "ExternalCADModelCompoundHarmonicAnalysis",
    "FaceGearCompoundHarmonicAnalysis",
    "FaceGearMeshCompoundHarmonicAnalysis",
    "FaceGearSetCompoundHarmonicAnalysis",
    "FEPartCompoundHarmonicAnalysis",
    "FlexiblePinAssemblyCompoundHarmonicAnalysis",
    "GearCompoundHarmonicAnalysis",
    "GearMeshCompoundHarmonicAnalysis",
    "GearSetCompoundHarmonicAnalysis",
    "GuideDxfModelCompoundHarmonicAnalysis",
    "HypoidGearCompoundHarmonicAnalysis",
    "HypoidGearMeshCompoundHarmonicAnalysis",
    "HypoidGearSetCompoundHarmonicAnalysis",
    "InterMountableComponentConnectionCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundHarmonicAnalysis",
    "MassDiscCompoundHarmonicAnalysis",
    "MeasurementComponentCompoundHarmonicAnalysis",
    "MicrophoneArrayCompoundHarmonicAnalysis",
    "MicrophoneCompoundHarmonicAnalysis",
    "MountableComponentCompoundHarmonicAnalysis",
    "OilSealCompoundHarmonicAnalysis",
    "PartCompoundHarmonicAnalysis",
    "PartToPartShearCouplingCompoundHarmonicAnalysis",
    "PartToPartShearCouplingConnectionCompoundHarmonicAnalysis",
    "PartToPartShearCouplingHalfCompoundHarmonicAnalysis",
    "PlanetaryConnectionCompoundHarmonicAnalysis",
    "PlanetaryGearSetCompoundHarmonicAnalysis",
    "PlanetCarrierCompoundHarmonicAnalysis",
    "PointLoadCompoundHarmonicAnalysis",
    "PowerLoadCompoundHarmonicAnalysis",
    "PulleyCompoundHarmonicAnalysis",
    "RingPinsCompoundHarmonicAnalysis",
    "RingPinsToDiscConnectionCompoundHarmonicAnalysis",
    "RollingRingAssemblyCompoundHarmonicAnalysis",
    "RollingRingCompoundHarmonicAnalysis",
    "RollingRingConnectionCompoundHarmonicAnalysis",
    "RootAssemblyCompoundHarmonicAnalysis",
    "ShaftCompoundHarmonicAnalysis",
    "ShaftHubConnectionCompoundHarmonicAnalysis",
    "ShaftToMountableComponentConnectionCompoundHarmonicAnalysis",
    "SpecialisedAssemblyCompoundHarmonicAnalysis",
    "SpiralBevelGearCompoundHarmonicAnalysis",
    "SpiralBevelGearMeshCompoundHarmonicAnalysis",
    "SpiralBevelGearSetCompoundHarmonicAnalysis",
    "SpringDamperCompoundHarmonicAnalysis",
    "SpringDamperConnectionCompoundHarmonicAnalysis",
    "SpringDamperHalfCompoundHarmonicAnalysis",
    "StraightBevelDiffGearCompoundHarmonicAnalysis",
    "StraightBevelDiffGearMeshCompoundHarmonicAnalysis",
    "StraightBevelDiffGearSetCompoundHarmonicAnalysis",
    "StraightBevelGearCompoundHarmonicAnalysis",
    "StraightBevelGearMeshCompoundHarmonicAnalysis",
    "StraightBevelGearSetCompoundHarmonicAnalysis",
    "StraightBevelPlanetGearCompoundHarmonicAnalysis",
    "StraightBevelSunGearCompoundHarmonicAnalysis",
    "SynchroniserCompoundHarmonicAnalysis",
    "SynchroniserHalfCompoundHarmonicAnalysis",
    "SynchroniserPartCompoundHarmonicAnalysis",
    "SynchroniserSleeveCompoundHarmonicAnalysis",
    "TorqueConverterCompoundHarmonicAnalysis",
    "TorqueConverterConnectionCompoundHarmonicAnalysis",
    "TorqueConverterPumpCompoundHarmonicAnalysis",
    "TorqueConverterTurbineCompoundHarmonicAnalysis",
    "UnbalancedMassCompoundHarmonicAnalysis",
    "VirtualComponentCompoundHarmonicAnalysis",
    "WormGearCompoundHarmonicAnalysis",
    "WormGearMeshCompoundHarmonicAnalysis",
    "WormGearSetCompoundHarmonicAnalysis",
    "ZerolBevelGearCompoundHarmonicAnalysis",
    "ZerolBevelGearMeshCompoundHarmonicAnalysis",
    "ZerolBevelGearSetCompoundHarmonicAnalysis",
)
