"""SquareMatrix"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.math_utility import _1742

_SQUARE_MATRIX = python_net_import("SMT.MastaAPI.MathUtility", "SquareMatrix")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.math_utility import _1727

    Self = TypeVar("Self", bound="SquareMatrix")
    CastSelf = TypeVar("CastSelf", bound="SquareMatrix._Cast_SquareMatrix")


__docformat__ = "restructuredtext en"
__all__ = ("SquareMatrix",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SquareMatrix:
    """Special nested class for casting SquareMatrix to subclasses."""

    __parent__: "SquareMatrix"

    @property
    def real_matrix(self: "CastSelf") -> "_1742.RealMatrix":
        return self.__parent__._cast(_1742.RealMatrix)

    @property
    def generic_matrix(self: "CastSelf") -> "_1727.GenericMatrix":
        from mastapy._private.math_utility import _1727

        return self.__parent__._cast(_1727.GenericMatrix)

    @property
    def square_matrix(self: "CastSelf") -> "SquareMatrix":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SquareMatrix(_1742.RealMatrix):
    """SquareMatrix

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SQUARE_MATRIX

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_SquareMatrix":
        """Cast to another type.

        Returns:
            _Cast_SquareMatrix
        """
        return _Cast_SquareMatrix(self)
