"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.nodal_analysis.component_mode_synthesis._322 import (
        AddNodeToGroupByID,
    )
    from mastapy._private.nodal_analysis.component_mode_synthesis._323 import (
        CMSElementFaceGroup,
    )
    from mastapy._private.nodal_analysis.component_mode_synthesis._324 import (
        CMSElementFaceGroupOfAllFreeFaces,
    )
    from mastapy._private.nodal_analysis.component_mode_synthesis._325 import CMSModel
    from mastapy._private.nodal_analysis.component_mode_synthesis._326 import (
        CMSNodeGroup,
    )
    from mastapy._private.nodal_analysis.component_mode_synthesis._327 import CMSOptions
    from mastapy._private.nodal_analysis.component_mode_synthesis._328 import CMSResults
    from mastapy._private.nodal_analysis.component_mode_synthesis._329 import (
        FESectionResults,
    )
    from mastapy._private.nodal_analysis.component_mode_synthesis._330 import (
        HarmonicCMSResults,
    )
    from mastapy._private.nodal_analysis.component_mode_synthesis._331 import (
        ModalCMSResults,
    )
    from mastapy._private.nodal_analysis.component_mode_synthesis._332 import (
        RealCMSResults,
    )
    from mastapy._private.nodal_analysis.component_mode_synthesis._333 import (
        ReductionModeType,
    )
    from mastapy._private.nodal_analysis.component_mode_synthesis._334 import (
        SoftwareUsedForReductionType,
    )
    from mastapy._private.nodal_analysis.component_mode_synthesis._335 import (
        StaticCMSResults,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.nodal_analysis.component_mode_synthesis._322": ["AddNodeToGroupByID"],
        "_private.nodal_analysis.component_mode_synthesis._323": [
            "CMSElementFaceGroup"
        ],
        "_private.nodal_analysis.component_mode_synthesis._324": [
            "CMSElementFaceGroupOfAllFreeFaces"
        ],
        "_private.nodal_analysis.component_mode_synthesis._325": ["CMSModel"],
        "_private.nodal_analysis.component_mode_synthesis._326": ["CMSNodeGroup"],
        "_private.nodal_analysis.component_mode_synthesis._327": ["CMSOptions"],
        "_private.nodal_analysis.component_mode_synthesis._328": ["CMSResults"],
        "_private.nodal_analysis.component_mode_synthesis._329": ["FESectionResults"],
        "_private.nodal_analysis.component_mode_synthesis._330": ["HarmonicCMSResults"],
        "_private.nodal_analysis.component_mode_synthesis._331": ["ModalCMSResults"],
        "_private.nodal_analysis.component_mode_synthesis._332": ["RealCMSResults"],
        "_private.nodal_analysis.component_mode_synthesis._333": ["ReductionModeType"],
        "_private.nodal_analysis.component_mode_synthesis._334": [
            "SoftwareUsedForReductionType"
        ],
        "_private.nodal_analysis.component_mode_synthesis._335": ["StaticCMSResults"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AddNodeToGroupByID",
    "CMSElementFaceGroup",
    "CMSElementFaceGroupOfAllFreeFaces",
    "CMSModel",
    "CMSNodeGroup",
    "CMSOptions",
    "CMSResults",
    "FESectionResults",
    "HarmonicCMSResults",
    "ModalCMSResults",
    "RealCMSResults",
    "ReductionModeType",
    "SoftwareUsedForReductionType",
    "StaticCMSResults",
)
