"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7047 import (
        AbstractAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7048 import (
        AbstractShaftCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7049 import (
        AbstractShaftOrHousingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7050 import (
        AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7051 import (
        AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7052 import (
        AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7053 import (
        AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7054 import (
        AssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7055 import (
        BearingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7056 import (
        BeltConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7057 import (
        BeltDriveCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7058 import (
        BevelDifferentialGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7059 import (
        BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7060 import (
        BevelDifferentialGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7061 import (
        BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7062 import (
        BevelDifferentialSunGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7063 import (
        BevelGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7064 import (
        BevelGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7065 import (
        BevelGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7066 import (
        BoltCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7067 import (
        BoltedJointCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7068 import (
        ClutchCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7069 import (
        ClutchConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7070 import (
        ClutchHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7071 import (
        CoaxialConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7072 import (
        ComponentCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7073 import (
        ConceptCouplingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7074 import (
        ConceptCouplingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7075 import (
        ConceptCouplingHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7076 import (
        ConceptGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7077 import (
        ConceptGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7078 import (
        ConceptGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7079 import (
        ConicalGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7080 import (
        ConicalGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7081 import (
        ConicalGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7082 import (
        ConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7083 import (
        ConnectorCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7084 import (
        CouplingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7085 import (
        CouplingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7086 import (
        CouplingHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7087 import (
        CVTBeltConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7088 import (
        CVTCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7089 import (
        CVTPulleyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7090 import (
        CycloidalAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7091 import (
        CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7092 import (
        CycloidalDiscCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7093 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7094 import (
        CylindricalGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7095 import (
        CylindricalGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7096 import (
        CylindricalGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7097 import (
        CylindricalPlanetGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7098 import (
        DatumCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7099 import (
        ExternalCADModelCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7100 import (
        FaceGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7101 import (
        FaceGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7102 import (
        FaceGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7103 import (
        FEPartCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7104 import (
        FlexiblePinAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7105 import (
        GearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7106 import (
        GearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7107 import (
        GearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7108 import (
        GuideDxfModelCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7109 import (
        HypoidGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7110 import (
        HypoidGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7111 import (
        HypoidGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7112 import (
        InterMountableComponentConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7113 import (
        KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7114 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7115 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7116 import (
        KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7117 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7118 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7119 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7120 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7121 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7122 import (
        MassDiscCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7123 import (
        MeasurementComponentCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7124 import (
        MicrophoneArrayCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7125 import (
        MicrophoneCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7126 import (
        MountableComponentCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7127 import (
        OilSealCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7128 import (
        PartCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7129 import (
        PartToPartShearCouplingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7130 import (
        PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7131 import (
        PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7132 import (
        PlanetaryConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7133 import (
        PlanetaryGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7134 import (
        PlanetCarrierCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7135 import (
        PointLoadCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7136 import (
        PowerLoadCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7137 import (
        PulleyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7138 import (
        RingPinsCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7139 import (
        RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7140 import (
        RollingRingAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7141 import (
        RollingRingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7142 import (
        RollingRingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7143 import (
        RootAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7144 import (
        ShaftCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7145 import (
        ShaftHubConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7146 import (
        ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7147 import (
        SpecialisedAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7148 import (
        SpiralBevelGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7149 import (
        SpiralBevelGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7150 import (
        SpiralBevelGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7151 import (
        SpringDamperCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7152 import (
        SpringDamperConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7153 import (
        SpringDamperHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7154 import (
        StraightBevelDiffGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7155 import (
        StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7156 import (
        StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7157 import (
        StraightBevelGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7158 import (
        StraightBevelGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7159 import (
        StraightBevelGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7160 import (
        StraightBevelPlanetGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7161 import (
        StraightBevelSunGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7162 import (
        SynchroniserCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7163 import (
        SynchroniserHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7164 import (
        SynchroniserPartCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7165 import (
        SynchroniserSleeveCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7166 import (
        TorqueConverterCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7167 import (
        TorqueConverterConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7168 import (
        TorqueConverterPumpCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7169 import (
        TorqueConverterTurbineCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7170 import (
        UnbalancedMassCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7171 import (
        VirtualComponentCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7172 import (
        WormGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7173 import (
        WormGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7174 import (
        WormGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7175 import (
        ZerolBevelGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7176 import (
        ZerolBevelGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._7177 import (
        ZerolBevelGearSetCompoundCriticalSpeedAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7047": [
            "AbstractAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7048": [
            "AbstractShaftCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7049": [
            "AbstractShaftOrHousingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7050": [
            "AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7051": [
            "AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7052": [
            "AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7053": [
            "AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7054": [
            "AssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7055": [
            "BearingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7056": [
            "BeltConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7057": [
            "BeltDriveCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7058": [
            "BevelDifferentialGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7059": [
            "BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7060": [
            "BevelDifferentialGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7061": [
            "BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7062": [
            "BevelDifferentialSunGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7063": [
            "BevelGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7064": [
            "BevelGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7065": [
            "BevelGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7066": [
            "BoltCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7067": [
            "BoltedJointCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7068": [
            "ClutchCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7069": [
            "ClutchConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7070": [
            "ClutchHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7071": [
            "CoaxialConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7072": [
            "ComponentCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7073": [
            "ConceptCouplingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7074": [
            "ConceptCouplingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7075": [
            "ConceptCouplingHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7076": [
            "ConceptGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7077": [
            "ConceptGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7078": [
            "ConceptGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7079": [
            "ConicalGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7080": [
            "ConicalGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7081": [
            "ConicalGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7082": [
            "ConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7083": [
            "ConnectorCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7084": [
            "CouplingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7085": [
            "CouplingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7086": [
            "CouplingHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7087": [
            "CVTBeltConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7088": [
            "CVTCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7089": [
            "CVTPulleyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7090": [
            "CycloidalAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7091": [
            "CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7092": [
            "CycloidalDiscCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7093": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7094": [
            "CylindricalGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7095": [
            "CylindricalGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7096": [
            "CylindricalGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7097": [
            "CylindricalPlanetGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7098": [
            "DatumCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7099": [
            "ExternalCADModelCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7100": [
            "FaceGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7101": [
            "FaceGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7102": [
            "FaceGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7103": [
            "FEPartCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7104": [
            "FlexiblePinAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7105": [
            "GearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7106": [
            "GearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7107": [
            "GearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7108": [
            "GuideDxfModelCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7109": [
            "HypoidGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7110": [
            "HypoidGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7111": [
            "HypoidGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7112": [
            "InterMountableComponentConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7113": [
            "KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7114": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7115": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7116": [
            "KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7117": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7118": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7119": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7120": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7121": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7122": [
            "MassDiscCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7123": [
            "MeasurementComponentCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7124": [
            "MicrophoneArrayCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7125": [
            "MicrophoneCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7126": [
            "MountableComponentCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7127": [
            "OilSealCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7128": [
            "PartCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7129": [
            "PartToPartShearCouplingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7130": [
            "PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7131": [
            "PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7132": [
            "PlanetaryConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7133": [
            "PlanetaryGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7134": [
            "PlanetCarrierCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7135": [
            "PointLoadCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7136": [
            "PowerLoadCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7137": [
            "PulleyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7138": [
            "RingPinsCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7139": [
            "RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7140": [
            "RollingRingAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7141": [
            "RollingRingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7142": [
            "RollingRingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7143": [
            "RootAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7144": [
            "ShaftCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7145": [
            "ShaftHubConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7146": [
            "ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7147": [
            "SpecialisedAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7148": [
            "SpiralBevelGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7149": [
            "SpiralBevelGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7150": [
            "SpiralBevelGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7151": [
            "SpringDamperCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7152": [
            "SpringDamperConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7153": [
            "SpringDamperHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7154": [
            "StraightBevelDiffGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7155": [
            "StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7156": [
            "StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7157": [
            "StraightBevelGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7158": [
            "StraightBevelGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7159": [
            "StraightBevelGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7160": [
            "StraightBevelPlanetGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7161": [
            "StraightBevelSunGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7162": [
            "SynchroniserCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7163": [
            "SynchroniserHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7164": [
            "SynchroniserPartCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7165": [
            "SynchroniserSleeveCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7166": [
            "TorqueConverterCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7167": [
            "TorqueConverterConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7168": [
            "TorqueConverterPumpCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7169": [
            "TorqueConverterTurbineCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7170": [
            "UnbalancedMassCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7171": [
            "VirtualComponentCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7172": [
            "WormGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7173": [
            "WormGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7174": [
            "WormGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7175": [
            "ZerolBevelGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7176": [
            "ZerolBevelGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._7177": [
            "ZerolBevelGearSetCompoundCriticalSpeedAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundCriticalSpeedAnalysis",
    "AbstractShaftCompoundCriticalSpeedAnalysis",
    "AbstractShaftOrHousingCompoundCriticalSpeedAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis",
    "AssemblyCompoundCriticalSpeedAnalysis",
    "BearingCompoundCriticalSpeedAnalysis",
    "BeltConnectionCompoundCriticalSpeedAnalysis",
    "BeltDriveCompoundCriticalSpeedAnalysis",
    "BevelDifferentialGearCompoundCriticalSpeedAnalysis",
    "BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis",
    "BevelDifferentialGearSetCompoundCriticalSpeedAnalysis",
    "BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis",
    "BevelDifferentialSunGearCompoundCriticalSpeedAnalysis",
    "BevelGearCompoundCriticalSpeedAnalysis",
    "BevelGearMeshCompoundCriticalSpeedAnalysis",
    "BevelGearSetCompoundCriticalSpeedAnalysis",
    "BoltCompoundCriticalSpeedAnalysis",
    "BoltedJointCompoundCriticalSpeedAnalysis",
    "ClutchCompoundCriticalSpeedAnalysis",
    "ClutchConnectionCompoundCriticalSpeedAnalysis",
    "ClutchHalfCompoundCriticalSpeedAnalysis",
    "CoaxialConnectionCompoundCriticalSpeedAnalysis",
    "ComponentCompoundCriticalSpeedAnalysis",
    "ConceptCouplingCompoundCriticalSpeedAnalysis",
    "ConceptCouplingConnectionCompoundCriticalSpeedAnalysis",
    "ConceptCouplingHalfCompoundCriticalSpeedAnalysis",
    "ConceptGearCompoundCriticalSpeedAnalysis",
    "ConceptGearMeshCompoundCriticalSpeedAnalysis",
    "ConceptGearSetCompoundCriticalSpeedAnalysis",
    "ConicalGearCompoundCriticalSpeedAnalysis",
    "ConicalGearMeshCompoundCriticalSpeedAnalysis",
    "ConicalGearSetCompoundCriticalSpeedAnalysis",
    "ConnectionCompoundCriticalSpeedAnalysis",
    "ConnectorCompoundCriticalSpeedAnalysis",
    "CouplingCompoundCriticalSpeedAnalysis",
    "CouplingConnectionCompoundCriticalSpeedAnalysis",
    "CouplingHalfCompoundCriticalSpeedAnalysis",
    "CVTBeltConnectionCompoundCriticalSpeedAnalysis",
    "CVTCompoundCriticalSpeedAnalysis",
    "CVTPulleyCompoundCriticalSpeedAnalysis",
    "CycloidalAssemblyCompoundCriticalSpeedAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis",
    "CycloidalDiscCompoundCriticalSpeedAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis",
    "CylindricalGearCompoundCriticalSpeedAnalysis",
    "CylindricalGearMeshCompoundCriticalSpeedAnalysis",
    "CylindricalGearSetCompoundCriticalSpeedAnalysis",
    "CylindricalPlanetGearCompoundCriticalSpeedAnalysis",
    "DatumCompoundCriticalSpeedAnalysis",
    "ExternalCADModelCompoundCriticalSpeedAnalysis",
    "FaceGearCompoundCriticalSpeedAnalysis",
    "FaceGearMeshCompoundCriticalSpeedAnalysis",
    "FaceGearSetCompoundCriticalSpeedAnalysis",
    "FEPartCompoundCriticalSpeedAnalysis",
    "FlexiblePinAssemblyCompoundCriticalSpeedAnalysis",
    "GearCompoundCriticalSpeedAnalysis",
    "GearMeshCompoundCriticalSpeedAnalysis",
    "GearSetCompoundCriticalSpeedAnalysis",
    "GuideDxfModelCompoundCriticalSpeedAnalysis",
    "HypoidGearCompoundCriticalSpeedAnalysis",
    "HypoidGearMeshCompoundCriticalSpeedAnalysis",
    "HypoidGearSetCompoundCriticalSpeedAnalysis",
    "InterMountableComponentConnectionCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis",
    "MassDiscCompoundCriticalSpeedAnalysis",
    "MeasurementComponentCompoundCriticalSpeedAnalysis",
    "MicrophoneArrayCompoundCriticalSpeedAnalysis",
    "MicrophoneCompoundCriticalSpeedAnalysis",
    "MountableComponentCompoundCriticalSpeedAnalysis",
    "OilSealCompoundCriticalSpeedAnalysis",
    "PartCompoundCriticalSpeedAnalysis",
    "PartToPartShearCouplingCompoundCriticalSpeedAnalysis",
    "PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis",
    "PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis",
    "PlanetaryConnectionCompoundCriticalSpeedAnalysis",
    "PlanetaryGearSetCompoundCriticalSpeedAnalysis",
    "PlanetCarrierCompoundCriticalSpeedAnalysis",
    "PointLoadCompoundCriticalSpeedAnalysis",
    "PowerLoadCompoundCriticalSpeedAnalysis",
    "PulleyCompoundCriticalSpeedAnalysis",
    "RingPinsCompoundCriticalSpeedAnalysis",
    "RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis",
    "RollingRingAssemblyCompoundCriticalSpeedAnalysis",
    "RollingRingCompoundCriticalSpeedAnalysis",
    "RollingRingConnectionCompoundCriticalSpeedAnalysis",
    "RootAssemblyCompoundCriticalSpeedAnalysis",
    "ShaftCompoundCriticalSpeedAnalysis",
    "ShaftHubConnectionCompoundCriticalSpeedAnalysis",
    "ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis",
    "SpecialisedAssemblyCompoundCriticalSpeedAnalysis",
    "SpiralBevelGearCompoundCriticalSpeedAnalysis",
    "SpiralBevelGearMeshCompoundCriticalSpeedAnalysis",
    "SpiralBevelGearSetCompoundCriticalSpeedAnalysis",
    "SpringDamperCompoundCriticalSpeedAnalysis",
    "SpringDamperConnectionCompoundCriticalSpeedAnalysis",
    "SpringDamperHalfCompoundCriticalSpeedAnalysis",
    "StraightBevelDiffGearCompoundCriticalSpeedAnalysis",
    "StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis",
    "StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis",
    "StraightBevelGearCompoundCriticalSpeedAnalysis",
    "StraightBevelGearMeshCompoundCriticalSpeedAnalysis",
    "StraightBevelGearSetCompoundCriticalSpeedAnalysis",
    "StraightBevelPlanetGearCompoundCriticalSpeedAnalysis",
    "StraightBevelSunGearCompoundCriticalSpeedAnalysis",
    "SynchroniserCompoundCriticalSpeedAnalysis",
    "SynchroniserHalfCompoundCriticalSpeedAnalysis",
    "SynchroniserPartCompoundCriticalSpeedAnalysis",
    "SynchroniserSleeveCompoundCriticalSpeedAnalysis",
    "TorqueConverterCompoundCriticalSpeedAnalysis",
    "TorqueConverterConnectionCompoundCriticalSpeedAnalysis",
    "TorqueConverterPumpCompoundCriticalSpeedAnalysis",
    "TorqueConverterTurbineCompoundCriticalSpeedAnalysis",
    "UnbalancedMassCompoundCriticalSpeedAnalysis",
    "VirtualComponentCompoundCriticalSpeedAnalysis",
    "WormGearCompoundCriticalSpeedAnalysis",
    "WormGearMeshCompoundCriticalSpeedAnalysis",
    "WormGearSetCompoundCriticalSpeedAnalysis",
    "ZerolBevelGearCompoundCriticalSpeedAnalysis",
    "ZerolBevelGearMeshCompoundCriticalSpeedAnalysis",
    "ZerolBevelGearSetCompoundCriticalSpeedAnalysis",
)
