"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5318 import (
        AbstractAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5319 import (
        AbstractShaftCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5320 import (
        AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5321 import (
        AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5322 import (
        AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5323 import (
        AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5324 import (
        AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5325 import (
        AssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5326 import (
        BearingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5327 import (
        BeltConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5328 import (
        BeltDriveCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5329 import (
        BevelDifferentialGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5330 import (
        BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5331 import (
        BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5332 import (
        BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5333 import (
        BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5334 import (
        BevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5335 import (
        BevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5336 import (
        BevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5337 import (
        BoltCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5338 import (
        BoltedJointCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5339 import (
        ClutchCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5340 import (
        ClutchConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5341 import (
        ClutchHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5342 import (
        CoaxialConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5343 import (
        ComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5344 import (
        ConceptCouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5345 import (
        ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5346 import (
        ConceptCouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5347 import (
        ConceptGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5348 import (
        ConceptGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5349 import (
        ConceptGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5350 import (
        ConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5351 import (
        ConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5352 import (
        ConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5353 import (
        ConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5354 import (
        ConnectorCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5355 import (
        CouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5356 import (
        CouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5357 import (
        CouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5358 import (
        CVTBeltConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5359 import (
        CVTCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5360 import (
        CVTPulleyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5361 import (
        CycloidalAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5362 import (
        CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5363 import (
        CycloidalDiscCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5364 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5365 import (
        CylindricalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5366 import (
        CylindricalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5367 import (
        CylindricalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5368 import (
        CylindricalPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5369 import (
        DatumCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5370 import (
        ExternalCADModelCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5371 import (
        FaceGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5372 import (
        FaceGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5373 import (
        FaceGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5374 import (
        FEPartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5375 import (
        FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5376 import (
        GearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5377 import (
        GearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5378 import (
        GearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5379 import (
        GuideDxfModelCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5380 import (
        HypoidGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5381 import (
        HypoidGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5382 import (
        HypoidGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5383 import (
        InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5384 import (
        KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5385 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5386 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5387 import (
        KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5388 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5389 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5390 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5391 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5392 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5393 import (
        MassDiscCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5394 import (
        MeasurementComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5395 import (
        MicrophoneArrayCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5396 import (
        MicrophoneCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5397 import (
        MountableComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5398 import (
        OilSealCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5399 import (
        PartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5400 import (
        PartToPartShearCouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5401 import (
        PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5402 import (
        PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5403 import (
        PlanetaryConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5404 import (
        PlanetaryGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5405 import (
        PlanetCarrierCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5406 import (
        PointLoadCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5407 import (
        PowerLoadCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5408 import (
        PulleyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5409 import (
        RingPinsCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5410 import (
        RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5411 import (
        RollingRingAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5412 import (
        RollingRingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5413 import (
        RollingRingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5414 import (
        RootAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5415 import (
        ShaftCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5416 import (
        ShaftHubConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5417 import (
        ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5418 import (
        SpecialisedAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5419 import (
        SpiralBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5420 import (
        SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5421 import (
        SpiralBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5422 import (
        SpringDamperCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5423 import (
        SpringDamperConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5424 import (
        SpringDamperHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5425 import (
        StraightBevelDiffGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5426 import (
        StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5427 import (
        StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5428 import (
        StraightBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5429 import (
        StraightBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5430 import (
        StraightBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5431 import (
        StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5432 import (
        StraightBevelSunGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5433 import (
        SynchroniserCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5434 import (
        SynchroniserHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5435 import (
        SynchroniserPartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5436 import (
        SynchroniserSleeveCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5437 import (
        TorqueConverterCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5438 import (
        TorqueConverterConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5439 import (
        TorqueConverterPumpCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5440 import (
        TorqueConverterTurbineCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5441 import (
        UnbalancedMassCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5442 import (
        VirtualComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5443 import (
        WormGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5444 import (
        WormGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5445 import (
        WormGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5446 import (
        ZerolBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5447 import (
        ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5448 import (
        ZerolBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5318": [
            "AbstractAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5319": [
            "AbstractShaftCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5320": [
            "AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5321": [
            "AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5322": [
            "AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5323": [
            "AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5324": [
            "AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5325": [
            "AssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5326": [
            "BearingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5327": [
            "BeltConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5328": [
            "BeltDriveCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5329": [
            "BevelDifferentialGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5330": [
            "BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5331": [
            "BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5332": [
            "BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5333": [
            "BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5334": [
            "BevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5335": [
            "BevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5336": [
            "BevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5337": [
            "BoltCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5338": [
            "BoltedJointCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5339": [
            "ClutchCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5340": [
            "ClutchConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5341": [
            "ClutchHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5342": [
            "CoaxialConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5343": [
            "ComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5344": [
            "ConceptCouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5345": [
            "ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5346": [
            "ConceptCouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5347": [
            "ConceptGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5348": [
            "ConceptGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5349": [
            "ConceptGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5350": [
            "ConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5351": [
            "ConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5352": [
            "ConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5353": [
            "ConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5354": [
            "ConnectorCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5355": [
            "CouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5356": [
            "CouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5357": [
            "CouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5358": [
            "CVTBeltConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5359": [
            "CVTCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5360": [
            "CVTPulleyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5361": [
            "CycloidalAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5362": [
            "CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5363": [
            "CycloidalDiscCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5364": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5365": [
            "CylindricalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5366": [
            "CylindricalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5367": [
            "CylindricalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5368": [
            "CylindricalPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5369": [
            "DatumCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5370": [
            "ExternalCADModelCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5371": [
            "FaceGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5372": [
            "FaceGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5373": [
            "FaceGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5374": [
            "FEPartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5375": [
            "FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5376": [
            "GearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5377": [
            "GearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5378": [
            "GearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5379": [
            "GuideDxfModelCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5380": [
            "HypoidGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5381": [
            "HypoidGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5382": [
            "HypoidGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5383": [
            "InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5384": [
            "KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5385": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5386": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5387": [
            "KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5388": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5389": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5390": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5391": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5392": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5393": [
            "MassDiscCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5394": [
            "MeasurementComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5395": [
            "MicrophoneArrayCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5396": [
            "MicrophoneCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5397": [
            "MountableComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5398": [
            "OilSealCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5399": [
            "PartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5400": [
            "PartToPartShearCouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5401": [
            "PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5402": [
            "PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5403": [
            "PlanetaryConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5404": [
            "PlanetaryGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5405": [
            "PlanetCarrierCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5406": [
            "PointLoadCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5407": [
            "PowerLoadCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5408": [
            "PulleyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5409": [
            "RingPinsCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5410": [
            "RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5411": [
            "RollingRingAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5412": [
            "RollingRingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5413": [
            "RollingRingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5414": [
            "RootAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5415": [
            "ShaftCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5416": [
            "ShaftHubConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5417": [
            "ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5418": [
            "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5419": [
            "SpiralBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5420": [
            "SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5421": [
            "SpiralBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5422": [
            "SpringDamperCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5423": [
            "SpringDamperConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5424": [
            "SpringDamperHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5425": [
            "StraightBevelDiffGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5426": [
            "StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5427": [
            "StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5428": [
            "StraightBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5429": [
            "StraightBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5430": [
            "StraightBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5431": [
            "StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5432": [
            "StraightBevelSunGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5433": [
            "SynchroniserCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5434": [
            "SynchroniserHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5435": [
            "SynchroniserPartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5436": [
            "SynchroniserSleeveCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5437": [
            "TorqueConverterCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5438": [
            "TorqueConverterConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5439": [
            "TorqueConverterPumpCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5440": [
            "TorqueConverterTurbineCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5441": [
            "UnbalancedMassCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5442": [
            "VirtualComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5443": [
            "WormGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5444": [
            "WormGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5445": [
            "WormGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5446": [
            "ZerolBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5447": [
            "ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5448": [
            "ZerolBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundModalAnalysisAtAStiffness",
    "AbstractShaftCompoundModalAnalysisAtAStiffness",
    "AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness",
    "AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness",
    "AssemblyCompoundModalAnalysisAtAStiffness",
    "BearingCompoundModalAnalysisAtAStiffness",
    "BeltConnectionCompoundModalAnalysisAtAStiffness",
    "BeltDriveCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness",
    "BevelGearCompoundModalAnalysisAtAStiffness",
    "BevelGearMeshCompoundModalAnalysisAtAStiffness",
    "BevelGearSetCompoundModalAnalysisAtAStiffness",
    "BoltCompoundModalAnalysisAtAStiffness",
    "BoltedJointCompoundModalAnalysisAtAStiffness",
    "ClutchCompoundModalAnalysisAtAStiffness",
    "ClutchConnectionCompoundModalAnalysisAtAStiffness",
    "ClutchHalfCompoundModalAnalysisAtAStiffness",
    "CoaxialConnectionCompoundModalAnalysisAtAStiffness",
    "ComponentCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingHalfCompoundModalAnalysisAtAStiffness",
    "ConceptGearCompoundModalAnalysisAtAStiffness",
    "ConceptGearMeshCompoundModalAnalysisAtAStiffness",
    "ConceptGearSetCompoundModalAnalysisAtAStiffness",
    "ConicalGearCompoundModalAnalysisAtAStiffness",
    "ConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "ConicalGearSetCompoundModalAnalysisAtAStiffness",
    "ConnectionCompoundModalAnalysisAtAStiffness",
    "ConnectorCompoundModalAnalysisAtAStiffness",
    "CouplingCompoundModalAnalysisAtAStiffness",
    "CouplingConnectionCompoundModalAnalysisAtAStiffness",
    "CouplingHalfCompoundModalAnalysisAtAStiffness",
    "CVTBeltConnectionCompoundModalAnalysisAtAStiffness",
    "CVTCompoundModalAnalysisAtAStiffness",
    "CVTPulleyCompoundModalAnalysisAtAStiffness",
    "CycloidalAssemblyCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness",
    "CylindricalGearCompoundModalAnalysisAtAStiffness",
    "CylindricalGearMeshCompoundModalAnalysisAtAStiffness",
    "CylindricalGearSetCompoundModalAnalysisAtAStiffness",
    "CylindricalPlanetGearCompoundModalAnalysisAtAStiffness",
    "DatumCompoundModalAnalysisAtAStiffness",
    "ExternalCADModelCompoundModalAnalysisAtAStiffness",
    "FaceGearCompoundModalAnalysisAtAStiffness",
    "FaceGearMeshCompoundModalAnalysisAtAStiffness",
    "FaceGearSetCompoundModalAnalysisAtAStiffness",
    "FEPartCompoundModalAnalysisAtAStiffness",
    "FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness",
    "GearCompoundModalAnalysisAtAStiffness",
    "GearMeshCompoundModalAnalysisAtAStiffness",
    "GearSetCompoundModalAnalysisAtAStiffness",
    "GuideDxfModelCompoundModalAnalysisAtAStiffness",
    "HypoidGearCompoundModalAnalysisAtAStiffness",
    "HypoidGearMeshCompoundModalAnalysisAtAStiffness",
    "HypoidGearSetCompoundModalAnalysisAtAStiffness",
    "InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness",
    "MassDiscCompoundModalAnalysisAtAStiffness",
    "MeasurementComponentCompoundModalAnalysisAtAStiffness",
    "MicrophoneArrayCompoundModalAnalysisAtAStiffness",
    "MicrophoneCompoundModalAnalysisAtAStiffness",
    "MountableComponentCompoundModalAnalysisAtAStiffness",
    "OilSealCompoundModalAnalysisAtAStiffness",
    "PartCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness",
    "PlanetaryConnectionCompoundModalAnalysisAtAStiffness",
    "PlanetaryGearSetCompoundModalAnalysisAtAStiffness",
    "PlanetCarrierCompoundModalAnalysisAtAStiffness",
    "PointLoadCompoundModalAnalysisAtAStiffness",
    "PowerLoadCompoundModalAnalysisAtAStiffness",
    "PulleyCompoundModalAnalysisAtAStiffness",
    "RingPinsCompoundModalAnalysisAtAStiffness",
    "RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness",
    "RollingRingAssemblyCompoundModalAnalysisAtAStiffness",
    "RollingRingCompoundModalAnalysisAtAStiffness",
    "RollingRingConnectionCompoundModalAnalysisAtAStiffness",
    "RootAssemblyCompoundModalAnalysisAtAStiffness",
    "ShaftCompoundModalAnalysisAtAStiffness",
    "ShaftHubConnectionCompoundModalAnalysisAtAStiffness",
    "ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearSetCompoundModalAnalysisAtAStiffness",
    "SpringDamperCompoundModalAnalysisAtAStiffness",
    "SpringDamperConnectionCompoundModalAnalysisAtAStiffness",
    "SpringDamperHalfCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearSetCompoundModalAnalysisAtAStiffness",
    "StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelSunGearCompoundModalAnalysisAtAStiffness",
    "SynchroniserCompoundModalAnalysisAtAStiffness",
    "SynchroniserHalfCompoundModalAnalysisAtAStiffness",
    "SynchroniserPartCompoundModalAnalysisAtAStiffness",
    "SynchroniserSleeveCompoundModalAnalysisAtAStiffness",
    "TorqueConverterCompoundModalAnalysisAtAStiffness",
    "TorqueConverterConnectionCompoundModalAnalysisAtAStiffness",
    "TorqueConverterPumpCompoundModalAnalysisAtAStiffness",
    "TorqueConverterTurbineCompoundModalAnalysisAtAStiffness",
    "UnbalancedMassCompoundModalAnalysisAtAStiffness",
    "VirtualComponentCompoundModalAnalysisAtAStiffness",
    "WormGearCompoundModalAnalysisAtAStiffness",
    "WormGearMeshCompoundModalAnalysisAtAStiffness",
    "WormGearSetCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearSetCompoundModalAnalysisAtAStiffness",
)
