"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.gear_set_pareto_optimiser._1027 import BarForPareto
    from mastapy._private.gears.gear_set_pareto_optimiser._1028 import (
        CandidateDisplayChoice,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1029 import ChartInfoBase
    from mastapy._private.gears.gear_set_pareto_optimiser._1030 import (
        CylindricalGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1031 import (
        DesignSpaceSearchBase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1032 import (
        DesignSpaceSearchCandidateBase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1033 import (
        FaceGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1034 import GearNameMapper
    from mastapy._private.gears.gear_set_pareto_optimiser._1035 import GearNamePicker
    from mastapy._private.gears.gear_set_pareto_optimiser._1036 import (
        GearSetOptimiserCandidate,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1037 import (
        GearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1038 import (
        HypoidGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1039 import (
        InputSliderForPareto,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1040 import LargerOrSmaller
    from mastapy._private.gears.gear_set_pareto_optimiser._1041 import (
        MicroGeometryDesignSpaceSearch,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1042 import (
        MicroGeometryDesignSpaceSearchCandidate,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1043 import (
        MicroGeometryDesignSpaceSearchChartInformation,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1044 import (
        MicroGeometryDesignSpaceSearchStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1045 import (
        MicroGeometryGearSetDesignSpaceSearch,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1046 import (
        MicroGeometryGearSetDesignSpaceSearchStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1047 import (
        MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1048 import (
        OptimisationTarget,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1049 import (
        ParetoConicalRatingOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1050 import (
        ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1051 import (
        ParetoCylindricalGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1052 import (
        ParetoCylindricalRatingOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1053 import (
        ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1054 import (
        ParetoFaceGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1055 import (
        ParetoFaceRatingOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1056 import (
        ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1057 import (
        ParetoHypoidGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1058 import (
        ParetoOptimiserChartInformation,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1059 import (
        ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1060 import (
        ParetoSpiralBevelGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1061 import (
        ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1062 import (
        ParetoStraightBevelGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1063 import (
        ReasonsForInvalidDesigns,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1064 import (
        SpiralBevelGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._1065 import (
        StraightBevelGearSetParetoOptimiser,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.gear_set_pareto_optimiser._1027": ["BarForPareto"],
        "_private.gears.gear_set_pareto_optimiser._1028": ["CandidateDisplayChoice"],
        "_private.gears.gear_set_pareto_optimiser._1029": ["ChartInfoBase"],
        "_private.gears.gear_set_pareto_optimiser._1030": [
            "CylindricalGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._1031": ["DesignSpaceSearchBase"],
        "_private.gears.gear_set_pareto_optimiser._1032": [
            "DesignSpaceSearchCandidateBase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1033": [
            "FaceGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._1034": ["GearNameMapper"],
        "_private.gears.gear_set_pareto_optimiser._1035": ["GearNamePicker"],
        "_private.gears.gear_set_pareto_optimiser._1036": ["GearSetOptimiserCandidate"],
        "_private.gears.gear_set_pareto_optimiser._1037": ["GearSetParetoOptimiser"],
        "_private.gears.gear_set_pareto_optimiser._1038": [
            "HypoidGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._1039": ["InputSliderForPareto"],
        "_private.gears.gear_set_pareto_optimiser._1040": ["LargerOrSmaller"],
        "_private.gears.gear_set_pareto_optimiser._1041": [
            "MicroGeometryDesignSpaceSearch"
        ],
        "_private.gears.gear_set_pareto_optimiser._1042": [
            "MicroGeometryDesignSpaceSearchCandidate"
        ],
        "_private.gears.gear_set_pareto_optimiser._1043": [
            "MicroGeometryDesignSpaceSearchChartInformation"
        ],
        "_private.gears.gear_set_pareto_optimiser._1044": [
            "MicroGeometryDesignSpaceSearchStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1045": [
            "MicroGeometryGearSetDesignSpaceSearch"
        ],
        "_private.gears.gear_set_pareto_optimiser._1046": [
            "MicroGeometryGearSetDesignSpaceSearchStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1047": [
            "MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1048": ["OptimisationTarget"],
        "_private.gears.gear_set_pareto_optimiser._1049": [
            "ParetoConicalRatingOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1050": [
            "ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1051": [
            "ParetoCylindricalGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1052": [
            "ParetoCylindricalRatingOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1053": [
            "ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1054": [
            "ParetoFaceGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1055": [
            "ParetoFaceRatingOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1056": [
            "ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1057": [
            "ParetoHypoidGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1058": [
            "ParetoOptimiserChartInformation"
        ],
        "_private.gears.gear_set_pareto_optimiser._1059": [
            "ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1060": [
            "ParetoSpiralBevelGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1061": [
            "ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1062": [
            "ParetoStraightBevelGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._1063": ["ReasonsForInvalidDesigns"],
        "_private.gears.gear_set_pareto_optimiser._1064": [
            "SpiralBevelGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._1065": [
            "StraightBevelGearSetParetoOptimiser"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BarForPareto",
    "CandidateDisplayChoice",
    "ChartInfoBase",
    "CylindricalGearSetParetoOptimiser",
    "DesignSpaceSearchBase",
    "DesignSpaceSearchCandidateBase",
    "FaceGearSetParetoOptimiser",
    "GearNameMapper",
    "GearNamePicker",
    "GearSetOptimiserCandidate",
    "GearSetParetoOptimiser",
    "HypoidGearSetParetoOptimiser",
    "InputSliderForPareto",
    "LargerOrSmaller",
    "MicroGeometryDesignSpaceSearch",
    "MicroGeometryDesignSpaceSearchCandidate",
    "MicroGeometryDesignSpaceSearchChartInformation",
    "MicroGeometryDesignSpaceSearchStrategyDatabase",
    "MicroGeometryGearSetDesignSpaceSearch",
    "MicroGeometryGearSetDesignSpaceSearchStrategyDatabase",
    "MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase",
    "OptimisationTarget",
    "ParetoConicalRatingOptimisationStrategyDatabase",
    "ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoCylindricalGearSetOptimisationStrategyDatabase",
    "ParetoCylindricalRatingOptimisationStrategyDatabase",
    "ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoFaceGearSetOptimisationStrategyDatabase",
    "ParetoFaceRatingOptimisationStrategyDatabase",
    "ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoHypoidGearSetOptimisationStrategyDatabase",
    "ParetoOptimiserChartInformation",
    "ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoSpiralBevelGearSetOptimisationStrategyDatabase",
    "ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoStraightBevelGearSetOptimisationStrategyDatabase",
    "ReasonsForInvalidDesigns",
    "SpiralBevelGearSetParetoOptimiser",
    "StraightBevelGearSetParetoOptimiser",
)
