"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3147 import (
        AbstractAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3148 import (
        AbstractShaftCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3149 import (
        AbstractShaftOrHousingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3150 import (
        AbstractShaftToMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3151 import (
        AGMAGleasonConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3152 import (
        AGMAGleasonConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3153 import (
        AGMAGleasonConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3154 import (
        AssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3155 import (
        BearingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3156 import (
        BeltConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3157 import (
        BeltDriveCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3158 import (
        BevelDifferentialGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3159 import (
        BevelDifferentialGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3160 import (
        BevelDifferentialGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3161 import (
        BevelDifferentialPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3162 import (
        BevelDifferentialSunGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3163 import (
        BevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3164 import (
        BevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3165 import (
        BevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3166 import (
        BoltCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3167 import (
        BoltedJointCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3168 import (
        ClutchCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3169 import (
        ClutchConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3170 import (
        ClutchHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3171 import (
        CoaxialConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3172 import (
        ComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3173 import (
        ConceptCouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3174 import (
        ConceptCouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3175 import (
        ConceptCouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3176 import (
        ConceptGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3177 import (
        ConceptGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3178 import (
        ConceptGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3179 import (
        ConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3180 import (
        ConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3181 import (
        ConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3182 import (
        ConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3183 import (
        ConnectorCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3184 import (
        CouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3185 import (
        CouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3186 import (
        CouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3187 import (
        CVTBeltConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3188 import (
        CVTCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3189 import (
        CVTPulleyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3190 import (
        CycloidalAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3191 import (
        CycloidalDiscCentralBearingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3192 import (
        CycloidalDiscCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3193 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3194 import (
        CylindricalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3195 import (
        CylindricalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3196 import (
        CylindricalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3197 import (
        CylindricalPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3198 import (
        DatumCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3199 import (
        DutyCycleEfficiencyResults,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3200 import (
        ExternalCADModelCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3201 import (
        FaceGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3202 import (
        FaceGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3203 import (
        FaceGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3204 import (
        FEPartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3205 import (
        FlexiblePinAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3206 import (
        GearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3207 import (
        GearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3208 import (
        GearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3209 import (
        GuideDxfModelCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3210 import (
        HypoidGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3211 import (
        HypoidGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3212 import (
        HypoidGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3213 import (
        InterMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3214 import (
        KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3215 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3216 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3217 import (
        KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3218 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3219 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3220 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3221 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3222 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3223 import (
        MassDiscCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3224 import (
        MeasurementComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3225 import (
        MicrophoneArrayCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3226 import (
        MicrophoneCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3227 import (
        MountableComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3228 import (
        OilSealCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3229 import (
        PartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3230 import (
        PartToPartShearCouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3231 import (
        PartToPartShearCouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3232 import (
        PartToPartShearCouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3233 import (
        PlanetaryConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3234 import (
        PlanetaryGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3235 import (
        PlanetCarrierCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3236 import (
        PointLoadCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3237 import (
        PowerLoadCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3238 import (
        PulleyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3239 import (
        RingPinsCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3240 import (
        RingPinsToDiscConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3241 import (
        RollingRingAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3242 import (
        RollingRingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3243 import (
        RollingRingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3244 import (
        RootAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3245 import (
        ShaftCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3246 import (
        ShaftDutyCycleSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3247 import (
        ShaftHubConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3248 import (
        ShaftToMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3249 import (
        SpecialisedAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3250 import (
        SpiralBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3251 import (
        SpiralBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3252 import (
        SpiralBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3253 import (
        SpringDamperCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3254 import (
        SpringDamperConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3255 import (
        SpringDamperHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3256 import (
        StraightBevelDiffGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3257 import (
        StraightBevelDiffGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3258 import (
        StraightBevelDiffGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3259 import (
        StraightBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3260 import (
        StraightBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3261 import (
        StraightBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3262 import (
        StraightBevelPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3263 import (
        StraightBevelSunGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3264 import (
        SynchroniserCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3265 import (
        SynchroniserHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3266 import (
        SynchroniserPartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3267 import (
        SynchroniserSleeveCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3268 import (
        TorqueConverterCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3269 import (
        TorqueConverterConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3270 import (
        TorqueConverterPumpCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3271 import (
        TorqueConverterTurbineCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3272 import (
        UnbalancedMassCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3273 import (
        VirtualComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3274 import (
        WormGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3275 import (
        WormGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3276 import (
        WormGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3277 import (
        ZerolBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3278 import (
        ZerolBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3279 import (
        ZerolBevelGearSetCompoundSystemDeflection,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.system_deflections.compound._3147": [
            "AbstractAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3148": [
            "AbstractShaftCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3149": [
            "AbstractShaftOrHousingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3150": [
            "AbstractShaftToMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3151": [
            "AGMAGleasonConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3152": [
            "AGMAGleasonConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3153": [
            "AGMAGleasonConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3154": [
            "AssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3155": [
            "BearingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3156": [
            "BeltConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3157": [
            "BeltDriveCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3158": [
            "BevelDifferentialGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3159": [
            "BevelDifferentialGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3160": [
            "BevelDifferentialGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3161": [
            "BevelDifferentialPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3162": [
            "BevelDifferentialSunGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3163": [
            "BevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3164": [
            "BevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3165": [
            "BevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3166": [
            "BoltCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3167": [
            "BoltedJointCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3168": [
            "ClutchCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3169": [
            "ClutchConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3170": [
            "ClutchHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3171": [
            "CoaxialConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3172": [
            "ComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3173": [
            "ConceptCouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3174": [
            "ConceptCouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3175": [
            "ConceptCouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3176": [
            "ConceptGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3177": [
            "ConceptGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3178": [
            "ConceptGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3179": [
            "ConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3180": [
            "ConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3181": [
            "ConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3182": [
            "ConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3183": [
            "ConnectorCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3184": [
            "CouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3185": [
            "CouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3186": [
            "CouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3187": [
            "CVTBeltConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3188": [
            "CVTCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3189": [
            "CVTPulleyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3190": [
            "CycloidalAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3191": [
            "CycloidalDiscCentralBearingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3192": [
            "CycloidalDiscCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3193": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3194": [
            "CylindricalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3195": [
            "CylindricalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3196": [
            "CylindricalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3197": [
            "CylindricalPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3198": [
            "DatumCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3199": [
            "DutyCycleEfficiencyResults"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3200": [
            "ExternalCADModelCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3201": [
            "FaceGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3202": [
            "FaceGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3203": [
            "FaceGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3204": [
            "FEPartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3205": [
            "FlexiblePinAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3206": [
            "GearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3207": [
            "GearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3208": [
            "GearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3209": [
            "GuideDxfModelCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3210": [
            "HypoidGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3211": [
            "HypoidGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3212": [
            "HypoidGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3213": [
            "InterMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3214": [
            "KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3215": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3216": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3217": [
            "KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3218": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3219": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3220": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3221": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3222": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3223": [
            "MassDiscCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3224": [
            "MeasurementComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3225": [
            "MicrophoneArrayCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3226": [
            "MicrophoneCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3227": [
            "MountableComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3228": [
            "OilSealCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3229": [
            "PartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3230": [
            "PartToPartShearCouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3231": [
            "PartToPartShearCouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3232": [
            "PartToPartShearCouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3233": [
            "PlanetaryConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3234": [
            "PlanetaryGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3235": [
            "PlanetCarrierCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3236": [
            "PointLoadCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3237": [
            "PowerLoadCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3238": [
            "PulleyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3239": [
            "RingPinsCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3240": [
            "RingPinsToDiscConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3241": [
            "RollingRingAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3242": [
            "RollingRingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3243": [
            "RollingRingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3244": [
            "RootAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3245": [
            "ShaftCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3246": [
            "ShaftDutyCycleSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3247": [
            "ShaftHubConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3248": [
            "ShaftToMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3249": [
            "SpecialisedAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3250": [
            "SpiralBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3251": [
            "SpiralBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3252": [
            "SpiralBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3253": [
            "SpringDamperCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3254": [
            "SpringDamperConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3255": [
            "SpringDamperHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3256": [
            "StraightBevelDiffGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3257": [
            "StraightBevelDiffGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3258": [
            "StraightBevelDiffGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3259": [
            "StraightBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3260": [
            "StraightBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3261": [
            "StraightBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3262": [
            "StraightBevelPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3263": [
            "StraightBevelSunGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3264": [
            "SynchroniserCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3265": [
            "SynchroniserHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3266": [
            "SynchroniserPartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3267": [
            "SynchroniserSleeveCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3268": [
            "TorqueConverterCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3269": [
            "TorqueConverterConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3270": [
            "TorqueConverterPumpCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3271": [
            "TorqueConverterTurbineCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3272": [
            "UnbalancedMassCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3273": [
            "VirtualComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3274": [
            "WormGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3275": [
            "WormGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3276": [
            "WormGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3277": [
            "ZerolBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3278": [
            "ZerolBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3279": [
            "ZerolBevelGearSetCompoundSystemDeflection"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundSystemDeflection",
    "AbstractShaftCompoundSystemDeflection",
    "AbstractShaftOrHousingCompoundSystemDeflection",
    "AbstractShaftToMountableComponentConnectionCompoundSystemDeflection",
    "AGMAGleasonConicalGearCompoundSystemDeflection",
    "AGMAGleasonConicalGearMeshCompoundSystemDeflection",
    "AGMAGleasonConicalGearSetCompoundSystemDeflection",
    "AssemblyCompoundSystemDeflection",
    "BearingCompoundSystemDeflection",
    "BeltConnectionCompoundSystemDeflection",
    "BeltDriveCompoundSystemDeflection",
    "BevelDifferentialGearCompoundSystemDeflection",
    "BevelDifferentialGearMeshCompoundSystemDeflection",
    "BevelDifferentialGearSetCompoundSystemDeflection",
    "BevelDifferentialPlanetGearCompoundSystemDeflection",
    "BevelDifferentialSunGearCompoundSystemDeflection",
    "BevelGearCompoundSystemDeflection",
    "BevelGearMeshCompoundSystemDeflection",
    "BevelGearSetCompoundSystemDeflection",
    "BoltCompoundSystemDeflection",
    "BoltedJointCompoundSystemDeflection",
    "ClutchCompoundSystemDeflection",
    "ClutchConnectionCompoundSystemDeflection",
    "ClutchHalfCompoundSystemDeflection",
    "CoaxialConnectionCompoundSystemDeflection",
    "ComponentCompoundSystemDeflection",
    "ConceptCouplingCompoundSystemDeflection",
    "ConceptCouplingConnectionCompoundSystemDeflection",
    "ConceptCouplingHalfCompoundSystemDeflection",
    "ConceptGearCompoundSystemDeflection",
    "ConceptGearMeshCompoundSystemDeflection",
    "ConceptGearSetCompoundSystemDeflection",
    "ConicalGearCompoundSystemDeflection",
    "ConicalGearMeshCompoundSystemDeflection",
    "ConicalGearSetCompoundSystemDeflection",
    "ConnectionCompoundSystemDeflection",
    "ConnectorCompoundSystemDeflection",
    "CouplingCompoundSystemDeflection",
    "CouplingConnectionCompoundSystemDeflection",
    "CouplingHalfCompoundSystemDeflection",
    "CVTBeltConnectionCompoundSystemDeflection",
    "CVTCompoundSystemDeflection",
    "CVTPulleyCompoundSystemDeflection",
    "CycloidalAssemblyCompoundSystemDeflection",
    "CycloidalDiscCentralBearingConnectionCompoundSystemDeflection",
    "CycloidalDiscCompoundSystemDeflection",
    "CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection",
    "CylindricalGearCompoundSystemDeflection",
    "CylindricalGearMeshCompoundSystemDeflection",
    "CylindricalGearSetCompoundSystemDeflection",
    "CylindricalPlanetGearCompoundSystemDeflection",
    "DatumCompoundSystemDeflection",
    "DutyCycleEfficiencyResults",
    "ExternalCADModelCompoundSystemDeflection",
    "FaceGearCompoundSystemDeflection",
    "FaceGearMeshCompoundSystemDeflection",
    "FaceGearSetCompoundSystemDeflection",
    "FEPartCompoundSystemDeflection",
    "FlexiblePinAssemblyCompoundSystemDeflection",
    "GearCompoundSystemDeflection",
    "GearMeshCompoundSystemDeflection",
    "GearSetCompoundSystemDeflection",
    "GuideDxfModelCompoundSystemDeflection",
    "HypoidGearCompoundSystemDeflection",
    "HypoidGearMeshCompoundSystemDeflection",
    "HypoidGearSetCompoundSystemDeflection",
    "InterMountableComponentConnectionCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection",
    "MassDiscCompoundSystemDeflection",
    "MeasurementComponentCompoundSystemDeflection",
    "MicrophoneArrayCompoundSystemDeflection",
    "MicrophoneCompoundSystemDeflection",
    "MountableComponentCompoundSystemDeflection",
    "OilSealCompoundSystemDeflection",
    "PartCompoundSystemDeflection",
    "PartToPartShearCouplingCompoundSystemDeflection",
    "PartToPartShearCouplingConnectionCompoundSystemDeflection",
    "PartToPartShearCouplingHalfCompoundSystemDeflection",
    "PlanetaryConnectionCompoundSystemDeflection",
    "PlanetaryGearSetCompoundSystemDeflection",
    "PlanetCarrierCompoundSystemDeflection",
    "PointLoadCompoundSystemDeflection",
    "PowerLoadCompoundSystemDeflection",
    "PulleyCompoundSystemDeflection",
    "RingPinsCompoundSystemDeflection",
    "RingPinsToDiscConnectionCompoundSystemDeflection",
    "RollingRingAssemblyCompoundSystemDeflection",
    "RollingRingCompoundSystemDeflection",
    "RollingRingConnectionCompoundSystemDeflection",
    "RootAssemblyCompoundSystemDeflection",
    "ShaftCompoundSystemDeflection",
    "ShaftDutyCycleSystemDeflection",
    "ShaftHubConnectionCompoundSystemDeflection",
    "ShaftToMountableComponentConnectionCompoundSystemDeflection",
    "SpecialisedAssemblyCompoundSystemDeflection",
    "SpiralBevelGearCompoundSystemDeflection",
    "SpiralBevelGearMeshCompoundSystemDeflection",
    "SpiralBevelGearSetCompoundSystemDeflection",
    "SpringDamperCompoundSystemDeflection",
    "SpringDamperConnectionCompoundSystemDeflection",
    "SpringDamperHalfCompoundSystemDeflection",
    "StraightBevelDiffGearCompoundSystemDeflection",
    "StraightBevelDiffGearMeshCompoundSystemDeflection",
    "StraightBevelDiffGearSetCompoundSystemDeflection",
    "StraightBevelGearCompoundSystemDeflection",
    "StraightBevelGearMeshCompoundSystemDeflection",
    "StraightBevelGearSetCompoundSystemDeflection",
    "StraightBevelPlanetGearCompoundSystemDeflection",
    "StraightBevelSunGearCompoundSystemDeflection",
    "SynchroniserCompoundSystemDeflection",
    "SynchroniserHalfCompoundSystemDeflection",
    "SynchroniserPartCompoundSystemDeflection",
    "SynchroniserSleeveCompoundSystemDeflection",
    "TorqueConverterCompoundSystemDeflection",
    "TorqueConverterConnectionCompoundSystemDeflection",
    "TorqueConverterPumpCompoundSystemDeflection",
    "TorqueConverterTurbineCompoundSystemDeflection",
    "UnbalancedMassCompoundSystemDeflection",
    "VirtualComponentCompoundSystemDeflection",
    "WormGearCompoundSystemDeflection",
    "WormGearMeshCompoundSystemDeflection",
    "WormGearSetCompoundSystemDeflection",
    "ZerolBevelGearCompoundSystemDeflection",
    "ZerolBevelGearMeshCompoundSystemDeflection",
    "ZerolBevelGearSetCompoundSystemDeflection",
)
