"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._784 import (
        ActiveProcessMethod,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._785 import (
        AnalysisMethod,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._786 import (
        CalculateLeadDeviationAccuracy,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._787 import (
        CalculatePitchDeviationAccuracy,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._788 import (
        CalculateProfileDeviationAccuracy,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._789 import (
        CentreDistanceOffsetMethod,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._790 import (
        CutterHeadSlideError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._791 import (
        GearMountingError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._792 import (
        HobbingProcessCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._793 import (
        HobbingProcessGearShape,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._794 import (
        HobbingProcessLeadCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._795 import (
        HobbingProcessMarkOnShaft,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._796 import (
        HobbingProcessPitchCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._797 import (
        HobbingProcessProfileCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._798 import (
        HobbingProcessSimulationInput,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._799 import (
        HobbingProcessSimulationNew,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._800 import (
        HobbingProcessSimulationViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._801 import (
        HobbingProcessTotalModificationCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._802 import (
        HobManufactureError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._803 import (
        HobResharpeningError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._804 import (
        ManufacturedQualityGrade,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._805 import (
        MountingError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._806 import (
        ProcessCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._807 import (
        ProcessGearShape,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._808 import (
        ProcessLeadCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._809 import (
        ProcessPitchCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._810 import (
        ProcessProfileCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._811 import (
        ProcessSimulationInput,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._812 import (
        ProcessSimulationNew,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._813 import (
        ProcessSimulationViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._814 import (
        ProcessTotalModificationCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._815 import (
        RackManufactureError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._816 import (
        RackMountingError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._817 import (
        WormGrinderManufactureError,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._818 import (
        WormGrindingCutterCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._819 import (
        WormGrindingLeadCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._820 import (
        WormGrindingProcessCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._821 import (
        WormGrindingProcessGearShape,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._822 import (
        WormGrindingProcessMarkOnShaft,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._823 import (
        WormGrindingProcessPitchCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._824 import (
        WormGrindingProcessProfileCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._825 import (
        WormGrindingProcessSimulationInput,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._826 import (
        WormGrindingProcessSimulationNew,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._827 import (
        WormGrindingProcessSimulationViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._828 import (
        WormGrindingProcessTotalModificationCalculation,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._784": [
            "ActiveProcessMethod"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._785": [
            "AnalysisMethod"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._786": [
            "CalculateLeadDeviationAccuracy"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._787": [
            "CalculatePitchDeviationAccuracy"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._788": [
            "CalculateProfileDeviationAccuracy"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._789": [
            "CentreDistanceOffsetMethod"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._790": [
            "CutterHeadSlideError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._791": [
            "GearMountingError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._792": [
            "HobbingProcessCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._793": [
            "HobbingProcessGearShape"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._794": [
            "HobbingProcessLeadCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._795": [
            "HobbingProcessMarkOnShaft"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._796": [
            "HobbingProcessPitchCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._797": [
            "HobbingProcessProfileCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._798": [
            "HobbingProcessSimulationInput"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._799": [
            "HobbingProcessSimulationNew"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._800": [
            "HobbingProcessSimulationViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._801": [
            "HobbingProcessTotalModificationCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._802": [
            "HobManufactureError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._803": [
            "HobResharpeningError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._804": [
            "ManufacturedQualityGrade"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._805": [
            "MountingError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._806": [
            "ProcessCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._807": [
            "ProcessGearShape"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._808": [
            "ProcessLeadCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._809": [
            "ProcessPitchCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._810": [
            "ProcessProfileCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._811": [
            "ProcessSimulationInput"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._812": [
            "ProcessSimulationNew"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._813": [
            "ProcessSimulationViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._814": [
            "ProcessTotalModificationCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._815": [
            "RackManufactureError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._816": [
            "RackMountingError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._817": [
            "WormGrinderManufactureError"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._818": [
            "WormGrindingCutterCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._819": [
            "WormGrindingLeadCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._820": [
            "WormGrindingProcessCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._821": [
            "WormGrindingProcessGearShape"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._822": [
            "WormGrindingProcessMarkOnShaft"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._823": [
            "WormGrindingProcessPitchCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._824": [
            "WormGrindingProcessProfileCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._825": [
            "WormGrindingProcessSimulationInput"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._826": [
            "WormGrindingProcessSimulationNew"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._827": [
            "WormGrindingProcessSimulationViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._828": [
            "WormGrindingProcessTotalModificationCalculation"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "ActiveProcessMethod",
    "AnalysisMethod",
    "CalculateLeadDeviationAccuracy",
    "CalculatePitchDeviationAccuracy",
    "CalculateProfileDeviationAccuracy",
    "CentreDistanceOffsetMethod",
    "CutterHeadSlideError",
    "GearMountingError",
    "HobbingProcessCalculation",
    "HobbingProcessGearShape",
    "HobbingProcessLeadCalculation",
    "HobbingProcessMarkOnShaft",
    "HobbingProcessPitchCalculation",
    "HobbingProcessProfileCalculation",
    "HobbingProcessSimulationInput",
    "HobbingProcessSimulationNew",
    "HobbingProcessSimulationViewModel",
    "HobbingProcessTotalModificationCalculation",
    "HobManufactureError",
    "HobResharpeningError",
    "ManufacturedQualityGrade",
    "MountingError",
    "ProcessCalculation",
    "ProcessGearShape",
    "ProcessLeadCalculation",
    "ProcessPitchCalculation",
    "ProcessProfileCalculation",
    "ProcessSimulationInput",
    "ProcessSimulationNew",
    "ProcessSimulationViewModel",
    "ProcessTotalModificationCalculation",
    "RackManufactureError",
    "RackMountingError",
    "WormGrinderManufactureError",
    "WormGrindingCutterCalculation",
    "WormGrindingLeadCalculation",
    "WormGrindingProcessCalculation",
    "WormGrindingProcessGearShape",
    "WormGrindingProcessMarkOnShaft",
    "WormGrindingProcessPitchCalculation",
    "WormGrindingProcessProfileCalculation",
    "WormGrindingProcessSimulationInput",
    "WormGrindingProcessSimulationNew",
    "WormGrindingProcessSimulationViewModel",
    "WormGrindingProcessTotalModificationCalculation",
)
