"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.utility.report._1971 import AdHocCustomTable
    from mastapy._private.utility.report._1972 import AxisSettings
    from mastapy._private.utility.report._1973 import BlankRow
    from mastapy._private.utility.report._1974 import CadPageOrientation
    from mastapy._private.utility.report._1975 import CadPageSize
    from mastapy._private.utility.report._1976 import CadTableBorderType
    from mastapy._private.utility.report._1977 import ChartDefinition
    from mastapy._private.utility.report._1978 import SMTChartPointShape
    from mastapy._private.utility.report._1979 import CustomChart
    from mastapy._private.utility.report._1980 import CustomDrawing
    from mastapy._private.utility.report._1981 import CustomGraphic
    from mastapy._private.utility.report._1982 import CustomImage
    from mastapy._private.utility.report._1983 import CustomReport
    from mastapy._private.utility.report._1984 import CustomReportCadDrawing
    from mastapy._private.utility.report._1985 import CustomReportChart
    from mastapy._private.utility.report._1986 import CustomReportChartItem
    from mastapy._private.utility.report._1987 import CustomReportColumn
    from mastapy._private.utility.report._1988 import CustomReportColumns
    from mastapy._private.utility.report._1989 import CustomReportDefinitionItem
    from mastapy._private.utility.report._1990 import CustomReportHorizontalLine
    from mastapy._private.utility.report._1991 import CustomReportHtmlItem
    from mastapy._private.utility.report._1992 import CustomReportItem
    from mastapy._private.utility.report._1993 import CustomReportItemContainer
    from mastapy._private.utility.report._1994 import (
        CustomReportItemContainerCollection,
    )
    from mastapy._private.utility.report._1995 import (
        CustomReportItemContainerCollectionBase,
    )
    from mastapy._private.utility.report._1996 import (
        CustomReportItemContainerCollectionItem,
    )
    from mastapy._private.utility.report._1997 import CustomReportKey
    from mastapy._private.utility.report._1998 import CustomReportMultiPropertyItem
    from mastapy._private.utility.report._1999 import CustomReportMultiPropertyItemBase
    from mastapy._private.utility.report._2000 import CustomReportNameableItem
    from mastapy._private.utility.report._2001 import CustomReportNamedItem
    from mastapy._private.utility.report._2002 import CustomReportPropertyItem
    from mastapy._private.utility.report._2003 import CustomReportStatusItem
    from mastapy._private.utility.report._2004 import CustomReportTab
    from mastapy._private.utility.report._2005 import CustomReportTabs
    from mastapy._private.utility.report._2006 import CustomReportText
    from mastapy._private.utility.report._2007 import CustomRow
    from mastapy._private.utility.report._2008 import CustomSubReport
    from mastapy._private.utility.report._2009 import CustomTable
    from mastapy._private.utility.report._2010 import DefinitionBooleanCheckOptions
    from mastapy._private.utility.report._2011 import DynamicCustomReportItem
    from mastapy._private.utility.report._2012 import FontStyle
    from mastapy._private.utility.report._2013 import FontWeight
    from mastapy._private.utility.report._2014 import HeadingSize
    from mastapy._private.utility.report._2015 import SimpleChartDefinition
    from mastapy._private.utility.report._2016 import UserTextRow
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.utility.report._1971": ["AdHocCustomTable"],
        "_private.utility.report._1972": ["AxisSettings"],
        "_private.utility.report._1973": ["BlankRow"],
        "_private.utility.report._1974": ["CadPageOrientation"],
        "_private.utility.report._1975": ["CadPageSize"],
        "_private.utility.report._1976": ["CadTableBorderType"],
        "_private.utility.report._1977": ["ChartDefinition"],
        "_private.utility.report._1978": ["SMTChartPointShape"],
        "_private.utility.report._1979": ["CustomChart"],
        "_private.utility.report._1980": ["CustomDrawing"],
        "_private.utility.report._1981": ["CustomGraphic"],
        "_private.utility.report._1982": ["CustomImage"],
        "_private.utility.report._1983": ["CustomReport"],
        "_private.utility.report._1984": ["CustomReportCadDrawing"],
        "_private.utility.report._1985": ["CustomReportChart"],
        "_private.utility.report._1986": ["CustomReportChartItem"],
        "_private.utility.report._1987": ["CustomReportColumn"],
        "_private.utility.report._1988": ["CustomReportColumns"],
        "_private.utility.report._1989": ["CustomReportDefinitionItem"],
        "_private.utility.report._1990": ["CustomReportHorizontalLine"],
        "_private.utility.report._1991": ["CustomReportHtmlItem"],
        "_private.utility.report._1992": ["CustomReportItem"],
        "_private.utility.report._1993": ["CustomReportItemContainer"],
        "_private.utility.report._1994": ["CustomReportItemContainerCollection"],
        "_private.utility.report._1995": ["CustomReportItemContainerCollectionBase"],
        "_private.utility.report._1996": ["CustomReportItemContainerCollectionItem"],
        "_private.utility.report._1997": ["CustomReportKey"],
        "_private.utility.report._1998": ["CustomReportMultiPropertyItem"],
        "_private.utility.report._1999": ["CustomReportMultiPropertyItemBase"],
        "_private.utility.report._2000": ["CustomReportNameableItem"],
        "_private.utility.report._2001": ["CustomReportNamedItem"],
        "_private.utility.report._2002": ["CustomReportPropertyItem"],
        "_private.utility.report._2003": ["CustomReportStatusItem"],
        "_private.utility.report._2004": ["CustomReportTab"],
        "_private.utility.report._2005": ["CustomReportTabs"],
        "_private.utility.report._2006": ["CustomReportText"],
        "_private.utility.report._2007": ["CustomRow"],
        "_private.utility.report._2008": ["CustomSubReport"],
        "_private.utility.report._2009": ["CustomTable"],
        "_private.utility.report._2010": ["DefinitionBooleanCheckOptions"],
        "_private.utility.report._2011": ["DynamicCustomReportItem"],
        "_private.utility.report._2012": ["FontStyle"],
        "_private.utility.report._2013": ["FontWeight"],
        "_private.utility.report._2014": ["HeadingSize"],
        "_private.utility.report._2015": ["SimpleChartDefinition"],
        "_private.utility.report._2016": ["UserTextRow"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AdHocCustomTable",
    "AxisSettings",
    "BlankRow",
    "CadPageOrientation",
    "CadPageSize",
    "CadTableBorderType",
    "ChartDefinition",
    "SMTChartPointShape",
    "CustomChart",
    "CustomDrawing",
    "CustomGraphic",
    "CustomImage",
    "CustomReport",
    "CustomReportCadDrawing",
    "CustomReportChart",
    "CustomReportChartItem",
    "CustomReportColumn",
    "CustomReportColumns",
    "CustomReportDefinitionItem",
    "CustomReportHorizontalLine",
    "CustomReportHtmlItem",
    "CustomReportItem",
    "CustomReportItemContainer",
    "CustomReportItemContainerCollection",
    "CustomReportItemContainerCollectionBase",
    "CustomReportItemContainerCollectionItem",
    "CustomReportKey",
    "CustomReportMultiPropertyItem",
    "CustomReportMultiPropertyItemBase",
    "CustomReportNameableItem",
    "CustomReportNamedItem",
    "CustomReportPropertyItem",
    "CustomReportStatusItem",
    "CustomReportTab",
    "CustomReportTabs",
    "CustomReportText",
    "CustomRow",
    "CustomSubReport",
    "CustomTable",
    "DefinitionBooleanCheckOptions",
    "DynamicCustomReportItem",
    "FontStyle",
    "FontWeight",
    "HeadingSize",
    "SimpleChartDefinition",
    "UserTextRow",
)
