"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.gear_designs.cylindrical._1124 import (
        AddendumModificationDistributionRule,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1125 import (
        BacklashSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1126 import BasicRackProfiles
    from mastapy._private.gears.gear_designs.cylindrical._1127 import (
        CaseHardeningProperties,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1128 import (
        CreateNewSuitableCutterOption,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1129 import (
        CrossedAxisCylindricalGearPair,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1130 import (
        CrossedAxisCylindricalGearPairLineContact,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1131 import (
        CrossedAxisCylindricalGearPairPointContact,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1132 import (
        Customer102DataSheetChangeLog,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1133 import (
        Customer102DataSheetChangeLogItem,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1134 import (
        Customer102DataSheetNote,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1135 import (
        Customer102DataSheetNotes,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1136 import (
        Customer102DataSheetTolerances,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1137 import (
        Customer102ToleranceDefinition,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1138 import (
        CylindricalGearAbstractRack,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1139 import (
        CylindricalGearAbstractRackFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1140 import (
        CylindricalGearBasicRack,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1141 import (
        CylindricalGearBasicRackFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1142 import (
        CylindricalGearCuttingOptions,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1143 import (
        CylindricalGearDefaults,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1144 import (
        CylindricalGearDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1145 import (
        CylindricalGearDesignConstraint,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1146 import (
        CylindricalGearDesignConstraints,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1147 import (
        CylindricalGearDesignConstraintsDatabase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1148 import (
        CylindricalGearDesignConstraintSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1149 import (
        CylindricalGearFlankDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1150 import (
        CylindricalGearMeshDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1151 import (
        CylindricalGearMeshFlankDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1152 import (
        CylindricalGearMicroGeometrySettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1153 import (
        CylindricalGearMicroGeometrySettingsDatabase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1154 import (
        CylindricalGearMicroGeometrySettingsItem,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1155 import (
        CylindricalGearPinionTypeCutter,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1156 import (
        CylindricalGearPinionTypeCutterFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1157 import (
        CylindricalGearProfileMeasurement,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1158 import (
        CylindricalGearProfileMeasurementType,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1159 import (
        CylindricalGearProfileModifications,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1160 import (
        CylindricalGearSetDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1161 import (
        CylindricalGearSetFlankDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1162 import (
        CylindricalGearSetMacroGeometryOptimiser,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1163 import (
        CylindricalGearSetManufacturingConfigurationSelection,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1164 import (
        CylindricalGearSetMicroGeometrySettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1165 import (
        CylindricalGearSetOptimisationWrapper,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1166 import (
        CylindricalGearTableMGItemDetail,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1167 import (
        CylindricalGearTableWithMGCharts,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1168 import (
        CylindricalGearToothThicknessSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1169 import (
        CylindricalMeshAngularBacklash,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1170 import (
        CylindricalMeshedGear,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1171 import (
        CylindricalMeshedGearFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1172 import (
        CylindricalMeshLinearBacklashSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1173 import (
        CylindricalPlanetaryGearSetDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1174 import (
        CylindricalPlanetGearDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1175 import (
        DIN3967AllowanceSeries,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1176 import (
        DIN3967ToleranceSeries,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1177 import (
        DoubleAxisScaleAndRange,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1178 import (
        FinishToothThicknessDesignSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1179 import GearFitSystems
    from mastapy._private.gears.gear_designs.cylindrical._1180 import (
        GearManufacturingConfigSetupViewModel,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1181 import (
        GearSetManufacturingConfigurationSetup,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1182 import (
        GeometrySpecificationType,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1183 import (
        HardenedMaterialProperties,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1184 import (
        HardnessProfileCalculationMethod,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1185 import HeatTreatmentType
    from mastapy._private.gears.gear_designs.cylindrical._1186 import ISO6336Geometry
    from mastapy._private.gears.gear_designs.cylindrical._1187 import (
        ISO6336GeometryBase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1188 import (
        ISO6336GeometryForShapedGears,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1189 import (
        ISO6336GeometryManufactured,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1190 import (
        LinearBacklashSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1191 import (
        LTCALoadCaseModifiableSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1192 import LTCASettings
    from mastapy._private.gears.gear_designs.cylindrical._1193 import (
        MicroGeometryConvention,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1194 import (
        MicroGeometryProfileConvention,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1195 import Micropitting
    from mastapy._private.gears.gear_designs.cylindrical._1196 import (
        MullerResidualStressDefinition,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1197 import (
        NamedPlanetAssemblyIndex,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1198 import (
        NamedPlanetSideBandAmplitudeFactor,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1199 import (
        PlanetGearSetPhaseRequirement,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1200 import (
        ReadonlyToothThicknessSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1201 import (
        RelativeMeasurementViewModel,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1202 import (
        RelativeValuesSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1203 import (
        ResidualStressCalculationMethod,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1204 import (
        RootStressSurfaceChartOption,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1205 import Scuffing
    from mastapy._private.gears.gear_designs.cylindrical._1206 import (
        ScuffingCoefficientOfFrictionMethods,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1207 import (
        ScuffingTemperatureMethodsAGMA,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1208 import (
        ScuffingTemperatureMethodsISO,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1209 import ShaperEdgeTypes
    from mastapy._private.gears.gear_designs.cylindrical._1210 import (
        SpurGearLoadSharingCodes,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1211 import StandardRack
    from mastapy._private.gears.gear_designs.cylindrical._1212 import StandardRackFlank
    from mastapy._private.gears.gear_designs.cylindrical._1213 import SurfaceRoughness
    from mastapy._private.gears.gear_designs.cylindrical._1214 import ThicknessType
    from mastapy._private.gears.gear_designs.cylindrical._1215 import (
        TiffAnalysisSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1216 import (
        TipAlterationCoefficientMethod,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1217 import (
        TolerancedMetalMeasurements,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1218 import (
        TolerancedValueSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1219 import (
        ToothFlankFractureAnalysisSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1220 import (
        ToothThicknessSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1221 import (
        ToothThicknessSpecificationBase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1222 import (
        TypeOfMechanismHousing,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1223 import Usage
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.gear_designs.cylindrical._1124": [
            "AddendumModificationDistributionRule"
        ],
        "_private.gears.gear_designs.cylindrical._1125": ["BacklashSpecification"],
        "_private.gears.gear_designs.cylindrical._1126": ["BasicRackProfiles"],
        "_private.gears.gear_designs.cylindrical._1127": ["CaseHardeningProperties"],
        "_private.gears.gear_designs.cylindrical._1128": [
            "CreateNewSuitableCutterOption"
        ],
        "_private.gears.gear_designs.cylindrical._1129": [
            "CrossedAxisCylindricalGearPair"
        ],
        "_private.gears.gear_designs.cylindrical._1130": [
            "CrossedAxisCylindricalGearPairLineContact"
        ],
        "_private.gears.gear_designs.cylindrical._1131": [
            "CrossedAxisCylindricalGearPairPointContact"
        ],
        "_private.gears.gear_designs.cylindrical._1132": [
            "Customer102DataSheetChangeLog"
        ],
        "_private.gears.gear_designs.cylindrical._1133": [
            "Customer102DataSheetChangeLogItem"
        ],
        "_private.gears.gear_designs.cylindrical._1134": ["Customer102DataSheetNote"],
        "_private.gears.gear_designs.cylindrical._1135": ["Customer102DataSheetNotes"],
        "_private.gears.gear_designs.cylindrical._1136": [
            "Customer102DataSheetTolerances"
        ],
        "_private.gears.gear_designs.cylindrical._1137": [
            "Customer102ToleranceDefinition"
        ],
        "_private.gears.gear_designs.cylindrical._1138": [
            "CylindricalGearAbstractRack"
        ],
        "_private.gears.gear_designs.cylindrical._1139": [
            "CylindricalGearAbstractRackFlank"
        ],
        "_private.gears.gear_designs.cylindrical._1140": ["CylindricalGearBasicRack"],
        "_private.gears.gear_designs.cylindrical._1141": [
            "CylindricalGearBasicRackFlank"
        ],
        "_private.gears.gear_designs.cylindrical._1142": [
            "CylindricalGearCuttingOptions"
        ],
        "_private.gears.gear_designs.cylindrical._1143": ["CylindricalGearDefaults"],
        "_private.gears.gear_designs.cylindrical._1144": ["CylindricalGearDesign"],
        "_private.gears.gear_designs.cylindrical._1145": [
            "CylindricalGearDesignConstraint"
        ],
        "_private.gears.gear_designs.cylindrical._1146": [
            "CylindricalGearDesignConstraints"
        ],
        "_private.gears.gear_designs.cylindrical._1147": [
            "CylindricalGearDesignConstraintsDatabase"
        ],
        "_private.gears.gear_designs.cylindrical._1148": [
            "CylindricalGearDesignConstraintSettings"
        ],
        "_private.gears.gear_designs.cylindrical._1149": ["CylindricalGearFlankDesign"],
        "_private.gears.gear_designs.cylindrical._1150": ["CylindricalGearMeshDesign"],
        "_private.gears.gear_designs.cylindrical._1151": [
            "CylindricalGearMeshFlankDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1152": [
            "CylindricalGearMicroGeometrySettings"
        ],
        "_private.gears.gear_designs.cylindrical._1153": [
            "CylindricalGearMicroGeometrySettingsDatabase"
        ],
        "_private.gears.gear_designs.cylindrical._1154": [
            "CylindricalGearMicroGeometrySettingsItem"
        ],
        "_private.gears.gear_designs.cylindrical._1155": [
            "CylindricalGearPinionTypeCutter"
        ],
        "_private.gears.gear_designs.cylindrical._1156": [
            "CylindricalGearPinionTypeCutterFlank"
        ],
        "_private.gears.gear_designs.cylindrical._1157": [
            "CylindricalGearProfileMeasurement"
        ],
        "_private.gears.gear_designs.cylindrical._1158": [
            "CylindricalGearProfileMeasurementType"
        ],
        "_private.gears.gear_designs.cylindrical._1159": [
            "CylindricalGearProfileModifications"
        ],
        "_private.gears.gear_designs.cylindrical._1160": ["CylindricalGearSetDesign"],
        "_private.gears.gear_designs.cylindrical._1161": [
            "CylindricalGearSetFlankDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1162": [
            "CylindricalGearSetMacroGeometryOptimiser"
        ],
        "_private.gears.gear_designs.cylindrical._1163": [
            "CylindricalGearSetManufacturingConfigurationSelection"
        ],
        "_private.gears.gear_designs.cylindrical._1164": [
            "CylindricalGearSetMicroGeometrySettings"
        ],
        "_private.gears.gear_designs.cylindrical._1165": [
            "CylindricalGearSetOptimisationWrapper"
        ],
        "_private.gears.gear_designs.cylindrical._1166": [
            "CylindricalGearTableMGItemDetail"
        ],
        "_private.gears.gear_designs.cylindrical._1167": [
            "CylindricalGearTableWithMGCharts"
        ],
        "_private.gears.gear_designs.cylindrical._1168": [
            "CylindricalGearToothThicknessSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1169": [
            "CylindricalMeshAngularBacklash"
        ],
        "_private.gears.gear_designs.cylindrical._1170": ["CylindricalMeshedGear"],
        "_private.gears.gear_designs.cylindrical._1171": ["CylindricalMeshedGearFlank"],
        "_private.gears.gear_designs.cylindrical._1172": [
            "CylindricalMeshLinearBacklashSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1173": [
            "CylindricalPlanetaryGearSetDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1174": [
            "CylindricalPlanetGearDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1175": ["DIN3967AllowanceSeries"],
        "_private.gears.gear_designs.cylindrical._1176": ["DIN3967ToleranceSeries"],
        "_private.gears.gear_designs.cylindrical._1177": ["DoubleAxisScaleAndRange"],
        "_private.gears.gear_designs.cylindrical._1178": [
            "FinishToothThicknessDesignSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1179": ["GearFitSystems"],
        "_private.gears.gear_designs.cylindrical._1180": [
            "GearManufacturingConfigSetupViewModel"
        ],
        "_private.gears.gear_designs.cylindrical._1181": [
            "GearSetManufacturingConfigurationSetup"
        ],
        "_private.gears.gear_designs.cylindrical._1182": ["GeometrySpecificationType"],
        "_private.gears.gear_designs.cylindrical._1183": ["HardenedMaterialProperties"],
        "_private.gears.gear_designs.cylindrical._1184": [
            "HardnessProfileCalculationMethod"
        ],
        "_private.gears.gear_designs.cylindrical._1185": ["HeatTreatmentType"],
        "_private.gears.gear_designs.cylindrical._1186": ["ISO6336Geometry"],
        "_private.gears.gear_designs.cylindrical._1187": ["ISO6336GeometryBase"],
        "_private.gears.gear_designs.cylindrical._1188": [
            "ISO6336GeometryForShapedGears"
        ],
        "_private.gears.gear_designs.cylindrical._1189": [
            "ISO6336GeometryManufactured"
        ],
        "_private.gears.gear_designs.cylindrical._1190": [
            "LinearBacklashSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1191": [
            "LTCALoadCaseModifiableSettings"
        ],
        "_private.gears.gear_designs.cylindrical._1192": ["LTCASettings"],
        "_private.gears.gear_designs.cylindrical._1193": ["MicroGeometryConvention"],
        "_private.gears.gear_designs.cylindrical._1194": [
            "MicroGeometryProfileConvention"
        ],
        "_private.gears.gear_designs.cylindrical._1195": ["Micropitting"],
        "_private.gears.gear_designs.cylindrical._1196": [
            "MullerResidualStressDefinition"
        ],
        "_private.gears.gear_designs.cylindrical._1197": ["NamedPlanetAssemblyIndex"],
        "_private.gears.gear_designs.cylindrical._1198": [
            "NamedPlanetSideBandAmplitudeFactor"
        ],
        "_private.gears.gear_designs.cylindrical._1199": [
            "PlanetGearSetPhaseRequirement"
        ],
        "_private.gears.gear_designs.cylindrical._1200": [
            "ReadonlyToothThicknessSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1201": [
            "RelativeMeasurementViewModel"
        ],
        "_private.gears.gear_designs.cylindrical._1202": [
            "RelativeValuesSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1203": [
            "ResidualStressCalculationMethod"
        ],
        "_private.gears.gear_designs.cylindrical._1204": [
            "RootStressSurfaceChartOption"
        ],
        "_private.gears.gear_designs.cylindrical._1205": ["Scuffing"],
        "_private.gears.gear_designs.cylindrical._1206": [
            "ScuffingCoefficientOfFrictionMethods"
        ],
        "_private.gears.gear_designs.cylindrical._1207": [
            "ScuffingTemperatureMethodsAGMA"
        ],
        "_private.gears.gear_designs.cylindrical._1208": [
            "ScuffingTemperatureMethodsISO"
        ],
        "_private.gears.gear_designs.cylindrical._1209": ["ShaperEdgeTypes"],
        "_private.gears.gear_designs.cylindrical._1210": ["SpurGearLoadSharingCodes"],
        "_private.gears.gear_designs.cylindrical._1211": ["StandardRack"],
        "_private.gears.gear_designs.cylindrical._1212": ["StandardRackFlank"],
        "_private.gears.gear_designs.cylindrical._1213": ["SurfaceRoughness"],
        "_private.gears.gear_designs.cylindrical._1214": ["ThicknessType"],
        "_private.gears.gear_designs.cylindrical._1215": ["TiffAnalysisSettings"],
        "_private.gears.gear_designs.cylindrical._1216": [
            "TipAlterationCoefficientMethod"
        ],
        "_private.gears.gear_designs.cylindrical._1217": [
            "TolerancedMetalMeasurements"
        ],
        "_private.gears.gear_designs.cylindrical._1218": [
            "TolerancedValueSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1219": [
            "ToothFlankFractureAnalysisSettings"
        ],
        "_private.gears.gear_designs.cylindrical._1220": [
            "ToothThicknessSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1221": [
            "ToothThicknessSpecificationBase"
        ],
        "_private.gears.gear_designs.cylindrical._1222": ["TypeOfMechanismHousing"],
        "_private.gears.gear_designs.cylindrical._1223": ["Usage"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AddendumModificationDistributionRule",
    "BacklashSpecification",
    "BasicRackProfiles",
    "CaseHardeningProperties",
    "CreateNewSuitableCutterOption",
    "CrossedAxisCylindricalGearPair",
    "CrossedAxisCylindricalGearPairLineContact",
    "CrossedAxisCylindricalGearPairPointContact",
    "Customer102DataSheetChangeLog",
    "Customer102DataSheetChangeLogItem",
    "Customer102DataSheetNote",
    "Customer102DataSheetNotes",
    "Customer102DataSheetTolerances",
    "Customer102ToleranceDefinition",
    "CylindricalGearAbstractRack",
    "CylindricalGearAbstractRackFlank",
    "CylindricalGearBasicRack",
    "CylindricalGearBasicRackFlank",
    "CylindricalGearCuttingOptions",
    "CylindricalGearDefaults",
    "CylindricalGearDesign",
    "CylindricalGearDesignConstraint",
    "CylindricalGearDesignConstraints",
    "CylindricalGearDesignConstraintsDatabase",
    "CylindricalGearDesignConstraintSettings",
    "CylindricalGearFlankDesign",
    "CylindricalGearMeshDesign",
    "CylindricalGearMeshFlankDesign",
    "CylindricalGearMicroGeometrySettings",
    "CylindricalGearMicroGeometrySettingsDatabase",
    "CylindricalGearMicroGeometrySettingsItem",
    "CylindricalGearPinionTypeCutter",
    "CylindricalGearPinionTypeCutterFlank",
    "CylindricalGearProfileMeasurement",
    "CylindricalGearProfileMeasurementType",
    "CylindricalGearProfileModifications",
    "CylindricalGearSetDesign",
    "CylindricalGearSetFlankDesign",
    "CylindricalGearSetMacroGeometryOptimiser",
    "CylindricalGearSetManufacturingConfigurationSelection",
    "CylindricalGearSetMicroGeometrySettings",
    "CylindricalGearSetOptimisationWrapper",
    "CylindricalGearTableMGItemDetail",
    "CylindricalGearTableWithMGCharts",
    "CylindricalGearToothThicknessSpecification",
    "CylindricalMeshAngularBacklash",
    "CylindricalMeshedGear",
    "CylindricalMeshedGearFlank",
    "CylindricalMeshLinearBacklashSpecification",
    "CylindricalPlanetaryGearSetDesign",
    "CylindricalPlanetGearDesign",
    "DIN3967AllowanceSeries",
    "DIN3967ToleranceSeries",
    "DoubleAxisScaleAndRange",
    "FinishToothThicknessDesignSpecification",
    "GearFitSystems",
    "GearManufacturingConfigSetupViewModel",
    "GearSetManufacturingConfigurationSetup",
    "GeometrySpecificationType",
    "HardenedMaterialProperties",
    "HardnessProfileCalculationMethod",
    "HeatTreatmentType",
    "ISO6336Geometry",
    "ISO6336GeometryBase",
    "ISO6336GeometryForShapedGears",
    "ISO6336GeometryManufactured",
    "LinearBacklashSpecification",
    "LTCALoadCaseModifiableSettings",
    "LTCASettings",
    "MicroGeometryConvention",
    "MicroGeometryProfileConvention",
    "Micropitting",
    "MullerResidualStressDefinition",
    "NamedPlanetAssemblyIndex",
    "NamedPlanetSideBandAmplitudeFactor",
    "PlanetGearSetPhaseRequirement",
    "ReadonlyToothThicknessSpecification",
    "RelativeMeasurementViewModel",
    "RelativeValuesSpecification",
    "ResidualStressCalculationMethod",
    "RootStressSurfaceChartOption",
    "Scuffing",
    "ScuffingCoefficientOfFrictionMethods",
    "ScuffingTemperatureMethodsAGMA",
    "ScuffingTemperatureMethodsISO",
    "ShaperEdgeTypes",
    "SpurGearLoadSharingCodes",
    "StandardRack",
    "StandardRackFlank",
    "SurfaceRoughness",
    "ThicknessType",
    "TiffAnalysisSettings",
    "TipAlterationCoefficientMethod",
    "TolerancedMetalMeasurements",
    "TolerancedValueSpecification",
    "ToothFlankFractureAnalysisSettings",
    "ToothThicknessSpecification",
    "ToothThicknessSpecificationBase",
    "TypeOfMechanismHousing",
    "Usage",
)
