"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4483 import (
        AbstractAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4484 import (
        AbstractShaftCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4485 import (
        AbstractShaftOrHousingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4486 import (
        AbstractShaftToMountableComponentConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4487 import (
        AGMAGleasonConicalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4488 import (
        AGMAGleasonConicalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4489 import (
        AGMAGleasonConicalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4490 import (
        AssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4491 import (
        BearingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4492 import (
        BeltConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4493 import (
        BeltDriveCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4494 import (
        BevelDifferentialGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4495 import (
        BevelDifferentialGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4496 import (
        BevelDifferentialGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4497 import (
        BevelDifferentialPlanetGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4498 import (
        BevelDifferentialSunGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4499 import (
        BevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4500 import (
        BevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4501 import (
        BevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4502 import (
        BoltCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4503 import (
        BoltedJointCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4504 import (
        ClutchCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4505 import (
        ClutchConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4506 import (
        ClutchHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4507 import (
        CoaxialConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4508 import (
        ComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4509 import (
        ConceptCouplingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4510 import (
        ConceptCouplingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4511 import (
        ConceptCouplingHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4512 import (
        ConceptGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4513 import (
        ConceptGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4514 import (
        ConceptGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4515 import (
        ConicalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4516 import (
        ConicalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4517 import (
        ConicalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4518 import (
        ConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4519 import (
        ConnectorCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4520 import (
        CouplingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4521 import (
        CouplingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4522 import (
        CouplingHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4523 import (
        CVTBeltConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4524 import (
        CVTCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4525 import (
        CVTPulleyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4526 import (
        CycloidalAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4527 import (
        CycloidalDiscCentralBearingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4528 import (
        CycloidalDiscCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4529 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4530 import (
        CylindricalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4531 import (
        CylindricalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4532 import (
        CylindricalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4533 import (
        CylindricalPlanetGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4534 import (
        DatumCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4535 import (
        ExternalCADModelCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4536 import (
        FaceGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4537 import (
        FaceGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4538 import (
        FaceGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4539 import (
        FEPartCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4540 import (
        FlexiblePinAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4541 import (
        GearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4542 import (
        GearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4543 import (
        GearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4544 import (
        GuideDxfModelCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4545 import (
        HypoidGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4546 import (
        HypoidGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4547 import (
        HypoidGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4548 import (
        InterMountableComponentConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4549 import (
        KlingelnbergCycloPalloidConicalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4550 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4551 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4552 import (
        KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4553 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4554 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4555 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4556 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4557 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4558 import (
        MassDiscCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4559 import (
        MeasurementComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4560 import (
        MicrophoneArrayCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4561 import (
        MicrophoneCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4562 import (
        MountableComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4563 import (
        OilSealCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4564 import (
        PartCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4565 import (
        PartToPartShearCouplingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4566 import (
        PartToPartShearCouplingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4567 import (
        PartToPartShearCouplingHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4568 import (
        PlanetaryConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4569 import (
        PlanetaryGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4570 import (
        PlanetCarrierCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4571 import (
        PointLoadCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4572 import (
        PowerLoadCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4573 import (
        PulleyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4574 import (
        RingPinsCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4575 import (
        RingPinsToDiscConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4576 import (
        RollingRingAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4577 import (
        RollingRingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4578 import (
        RollingRingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4579 import (
        RootAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4580 import (
        ShaftCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4581 import (
        ShaftHubConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4582 import (
        ShaftToMountableComponentConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4583 import (
        SpecialisedAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4584 import (
        SpiralBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4585 import (
        SpiralBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4586 import (
        SpiralBevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4587 import (
        SpringDamperCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4588 import (
        SpringDamperConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4589 import (
        SpringDamperHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4590 import (
        StraightBevelDiffGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4591 import (
        StraightBevelDiffGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4592 import (
        StraightBevelDiffGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4593 import (
        StraightBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4594 import (
        StraightBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4595 import (
        StraightBevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4596 import (
        StraightBevelPlanetGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4597 import (
        StraightBevelSunGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4598 import (
        SynchroniserCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4599 import (
        SynchroniserHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4600 import (
        SynchroniserPartCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4601 import (
        SynchroniserSleeveCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4602 import (
        TorqueConverterCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4603 import (
        TorqueConverterConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4604 import (
        TorqueConverterPumpCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4605 import (
        TorqueConverterTurbineCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4606 import (
        UnbalancedMassCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4607 import (
        VirtualComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4608 import (
        WormGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4609 import (
        WormGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4610 import (
        WormGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4611 import (
        ZerolBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4612 import (
        ZerolBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4613 import (
        ZerolBevelGearSetCompoundPowerFlow,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.power_flows.compound._4483": [
            "AbstractAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4484": [
            "AbstractShaftCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4485": [
            "AbstractShaftOrHousingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4486": [
            "AbstractShaftToMountableComponentConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4487": [
            "AGMAGleasonConicalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4488": [
            "AGMAGleasonConicalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4489": [
            "AGMAGleasonConicalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4490": [
            "AssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4491": [
            "BearingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4492": [
            "BeltConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4493": [
            "BeltDriveCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4494": [
            "BevelDifferentialGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4495": [
            "BevelDifferentialGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4496": [
            "BevelDifferentialGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4497": [
            "BevelDifferentialPlanetGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4498": [
            "BevelDifferentialSunGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4499": [
            "BevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4500": [
            "BevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4501": [
            "BevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4502": [
            "BoltCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4503": [
            "BoltedJointCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4504": [
            "ClutchCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4505": [
            "ClutchConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4506": [
            "ClutchHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4507": [
            "CoaxialConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4508": [
            "ComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4509": [
            "ConceptCouplingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4510": [
            "ConceptCouplingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4511": [
            "ConceptCouplingHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4512": [
            "ConceptGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4513": [
            "ConceptGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4514": [
            "ConceptGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4515": [
            "ConicalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4516": [
            "ConicalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4517": [
            "ConicalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4518": [
            "ConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4519": [
            "ConnectorCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4520": [
            "CouplingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4521": [
            "CouplingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4522": [
            "CouplingHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4523": [
            "CVTBeltConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4524": [
            "CVTCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4525": [
            "CVTPulleyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4526": [
            "CycloidalAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4527": [
            "CycloidalDiscCentralBearingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4528": [
            "CycloidalDiscCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4529": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4530": [
            "CylindricalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4531": [
            "CylindricalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4532": [
            "CylindricalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4533": [
            "CylindricalPlanetGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4534": [
            "DatumCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4535": [
            "ExternalCADModelCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4536": [
            "FaceGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4537": [
            "FaceGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4538": [
            "FaceGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4539": [
            "FEPartCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4540": [
            "FlexiblePinAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4541": [
            "GearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4542": [
            "GearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4543": [
            "GearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4544": [
            "GuideDxfModelCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4545": [
            "HypoidGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4546": [
            "HypoidGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4547": [
            "HypoidGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4548": [
            "InterMountableComponentConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4549": [
            "KlingelnbergCycloPalloidConicalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4550": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4551": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4552": [
            "KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4553": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4554": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4555": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4556": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4557": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4558": [
            "MassDiscCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4559": [
            "MeasurementComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4560": [
            "MicrophoneArrayCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4561": [
            "MicrophoneCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4562": [
            "MountableComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4563": [
            "OilSealCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4564": [
            "PartCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4565": [
            "PartToPartShearCouplingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4566": [
            "PartToPartShearCouplingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4567": [
            "PartToPartShearCouplingHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4568": [
            "PlanetaryConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4569": [
            "PlanetaryGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4570": [
            "PlanetCarrierCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4571": [
            "PointLoadCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4572": [
            "PowerLoadCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4573": [
            "PulleyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4574": [
            "RingPinsCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4575": [
            "RingPinsToDiscConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4576": [
            "RollingRingAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4577": [
            "RollingRingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4578": [
            "RollingRingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4579": [
            "RootAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4580": [
            "ShaftCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4581": [
            "ShaftHubConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4582": [
            "ShaftToMountableComponentConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4583": [
            "SpecialisedAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4584": [
            "SpiralBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4585": [
            "SpiralBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4586": [
            "SpiralBevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4587": [
            "SpringDamperCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4588": [
            "SpringDamperConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4589": [
            "SpringDamperHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4590": [
            "StraightBevelDiffGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4591": [
            "StraightBevelDiffGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4592": [
            "StraightBevelDiffGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4593": [
            "StraightBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4594": [
            "StraightBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4595": [
            "StraightBevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4596": [
            "StraightBevelPlanetGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4597": [
            "StraightBevelSunGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4598": [
            "SynchroniserCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4599": [
            "SynchroniserHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4600": [
            "SynchroniserPartCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4601": [
            "SynchroniserSleeveCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4602": [
            "TorqueConverterCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4603": [
            "TorqueConverterConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4604": [
            "TorqueConverterPumpCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4605": [
            "TorqueConverterTurbineCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4606": [
            "UnbalancedMassCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4607": [
            "VirtualComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4608": [
            "WormGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4609": [
            "WormGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4610": [
            "WormGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4611": [
            "ZerolBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4612": [
            "ZerolBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4613": [
            "ZerolBevelGearSetCompoundPowerFlow"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundPowerFlow",
    "AbstractShaftCompoundPowerFlow",
    "AbstractShaftOrHousingCompoundPowerFlow",
    "AbstractShaftToMountableComponentConnectionCompoundPowerFlow",
    "AGMAGleasonConicalGearCompoundPowerFlow",
    "AGMAGleasonConicalGearMeshCompoundPowerFlow",
    "AGMAGleasonConicalGearSetCompoundPowerFlow",
    "AssemblyCompoundPowerFlow",
    "BearingCompoundPowerFlow",
    "BeltConnectionCompoundPowerFlow",
    "BeltDriveCompoundPowerFlow",
    "BevelDifferentialGearCompoundPowerFlow",
    "BevelDifferentialGearMeshCompoundPowerFlow",
    "BevelDifferentialGearSetCompoundPowerFlow",
    "BevelDifferentialPlanetGearCompoundPowerFlow",
    "BevelDifferentialSunGearCompoundPowerFlow",
    "BevelGearCompoundPowerFlow",
    "BevelGearMeshCompoundPowerFlow",
    "BevelGearSetCompoundPowerFlow",
    "BoltCompoundPowerFlow",
    "BoltedJointCompoundPowerFlow",
    "ClutchCompoundPowerFlow",
    "ClutchConnectionCompoundPowerFlow",
    "ClutchHalfCompoundPowerFlow",
    "CoaxialConnectionCompoundPowerFlow",
    "ComponentCompoundPowerFlow",
    "ConceptCouplingCompoundPowerFlow",
    "ConceptCouplingConnectionCompoundPowerFlow",
    "ConceptCouplingHalfCompoundPowerFlow",
    "ConceptGearCompoundPowerFlow",
    "ConceptGearMeshCompoundPowerFlow",
    "ConceptGearSetCompoundPowerFlow",
    "ConicalGearCompoundPowerFlow",
    "ConicalGearMeshCompoundPowerFlow",
    "ConicalGearSetCompoundPowerFlow",
    "ConnectionCompoundPowerFlow",
    "ConnectorCompoundPowerFlow",
    "CouplingCompoundPowerFlow",
    "CouplingConnectionCompoundPowerFlow",
    "CouplingHalfCompoundPowerFlow",
    "CVTBeltConnectionCompoundPowerFlow",
    "CVTCompoundPowerFlow",
    "CVTPulleyCompoundPowerFlow",
    "CycloidalAssemblyCompoundPowerFlow",
    "CycloidalDiscCentralBearingConnectionCompoundPowerFlow",
    "CycloidalDiscCompoundPowerFlow",
    "CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow",
    "CylindricalGearCompoundPowerFlow",
    "CylindricalGearMeshCompoundPowerFlow",
    "CylindricalGearSetCompoundPowerFlow",
    "CylindricalPlanetGearCompoundPowerFlow",
    "DatumCompoundPowerFlow",
    "ExternalCADModelCompoundPowerFlow",
    "FaceGearCompoundPowerFlow",
    "FaceGearMeshCompoundPowerFlow",
    "FaceGearSetCompoundPowerFlow",
    "FEPartCompoundPowerFlow",
    "FlexiblePinAssemblyCompoundPowerFlow",
    "GearCompoundPowerFlow",
    "GearMeshCompoundPowerFlow",
    "GearSetCompoundPowerFlow",
    "GuideDxfModelCompoundPowerFlow",
    "HypoidGearCompoundPowerFlow",
    "HypoidGearMeshCompoundPowerFlow",
    "HypoidGearSetCompoundPowerFlow",
    "InterMountableComponentConnectionCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow",
    "MassDiscCompoundPowerFlow",
    "MeasurementComponentCompoundPowerFlow",
    "MicrophoneArrayCompoundPowerFlow",
    "MicrophoneCompoundPowerFlow",
    "MountableComponentCompoundPowerFlow",
    "OilSealCompoundPowerFlow",
    "PartCompoundPowerFlow",
    "PartToPartShearCouplingCompoundPowerFlow",
    "PartToPartShearCouplingConnectionCompoundPowerFlow",
    "PartToPartShearCouplingHalfCompoundPowerFlow",
    "PlanetaryConnectionCompoundPowerFlow",
    "PlanetaryGearSetCompoundPowerFlow",
    "PlanetCarrierCompoundPowerFlow",
    "PointLoadCompoundPowerFlow",
    "PowerLoadCompoundPowerFlow",
    "PulleyCompoundPowerFlow",
    "RingPinsCompoundPowerFlow",
    "RingPinsToDiscConnectionCompoundPowerFlow",
    "RollingRingAssemblyCompoundPowerFlow",
    "RollingRingCompoundPowerFlow",
    "RollingRingConnectionCompoundPowerFlow",
    "RootAssemblyCompoundPowerFlow",
    "ShaftCompoundPowerFlow",
    "ShaftHubConnectionCompoundPowerFlow",
    "ShaftToMountableComponentConnectionCompoundPowerFlow",
    "SpecialisedAssemblyCompoundPowerFlow",
    "SpiralBevelGearCompoundPowerFlow",
    "SpiralBevelGearMeshCompoundPowerFlow",
    "SpiralBevelGearSetCompoundPowerFlow",
    "SpringDamperCompoundPowerFlow",
    "SpringDamperConnectionCompoundPowerFlow",
    "SpringDamperHalfCompoundPowerFlow",
    "StraightBevelDiffGearCompoundPowerFlow",
    "StraightBevelDiffGearMeshCompoundPowerFlow",
    "StraightBevelDiffGearSetCompoundPowerFlow",
    "StraightBevelGearCompoundPowerFlow",
    "StraightBevelGearMeshCompoundPowerFlow",
    "StraightBevelGearSetCompoundPowerFlow",
    "StraightBevelPlanetGearCompoundPowerFlow",
    "StraightBevelSunGearCompoundPowerFlow",
    "SynchroniserCompoundPowerFlow",
    "SynchroniserHalfCompoundPowerFlow",
    "SynchroniserPartCompoundPowerFlow",
    "SynchroniserSleeveCompoundPowerFlow",
    "TorqueConverterCompoundPowerFlow",
    "TorqueConverterConnectionCompoundPowerFlow",
    "TorqueConverterPumpCompoundPowerFlow",
    "TorqueConverterTurbineCompoundPowerFlow",
    "UnbalancedMassCompoundPowerFlow",
    "VirtualComponentCompoundPowerFlow",
    "WormGearCompoundPowerFlow",
    "WormGearMeshCompoundPowerFlow",
    "WormGearSetCompoundPowerFlow",
    "ZerolBevelGearCompoundPowerFlow",
    "ZerolBevelGearMeshCompoundPowerFlow",
    "ZerolBevelGearSetCompoundPowerFlow",
)
