"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1381 import (
        BeamSectionType,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1382 import (
        ContactPairConstrainedSurfaceType,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1383 import (
        ContactPairReferenceSurfaceType,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1384 import (
        ElementPropertiesShellIntegrationRule,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1385 import (
        ElementPropertiesShellWallType,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1381": [
            "BeamSectionType"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1382": [
            "ContactPairConstrainedSurfaceType"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1383": [
            "ContactPairReferenceSurfaceType"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1384": [
            "ElementPropertiesShellIntegrationRule"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1385": [
            "ElementPropertiesShellWallType"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BeamSectionType",
    "ContactPairConstrainedSurfaceType",
    "ContactPairReferenceSurfaceType",
    "ElementPropertiesShellIntegrationRule",
    "ElementPropertiesShellWallType",
)
