"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import mixins
from mastapy._private.nodal_analysis.varying_input_components import _109

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_ConstraintType")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_ConstraintType",)


class EnumWithSelectedValue_ConstraintType(mixins.EnumWithSelectedValueMixin, Enum):
    """EnumWithSelectedValue_ConstraintType

    A specific implementation of 'EnumWithSelectedValue' for 'ConstraintType' types.
    """

    __qualname__ = "ConstraintType"

    @classmethod
    def wrapper_type(cls: "Type[EnumWithSelectedValue_ConstraintType]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_ConstraintType]",
    ) -> "_109.ConstraintType":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _109.ConstraintType
        """
        return _109.ConstraintType

    @classmethod
    def implicit_type(cls: "Type[EnumWithSelectedValue_ConstraintType]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _109.ConstraintType.type_()

    @property
    @exception_bridge
    def selected_value(self: "Self") -> "_109.ConstraintType":
        """mastapy.nodal_analysis.varying_input_components.ConstraintType

        Note:
            This property is readonly.
        """
        return None

    @property
    @exception_bridge
    def available_values(self: "Self") -> "List[_109.ConstraintType]":
        """List[mastapy.nodal_analysis.varying_input_components.ConstraintType]

        Note:
            This property is readonly.
        """
        return None
