"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6021 import (
        AbstractAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6022 import (
        AbstractPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6023 import (
        AbstractShaftHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6024 import (
        AbstractShaftOrHousingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6025 import (
        AbstractShaftToMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6026 import (
        AGMAGleasonConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6027 import (
        AGMAGleasonConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6028 import (
        AGMAGleasonConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6029 import (
        AssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6030 import (
        BearingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6031 import (
        BeltConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6032 import (
        BeltDriveHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6033 import (
        BevelDifferentialGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6034 import (
        BevelDifferentialGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6035 import (
        BevelDifferentialGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6036 import (
        BevelDifferentialPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6037 import (
        BevelDifferentialSunGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6038 import (
        BevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6039 import (
        BevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6040 import (
        BevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6041 import (
        BoltedJointHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6042 import (
        BoltHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6043 import (
        ClutchConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6044 import (
        ClutchHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6045 import (
        ClutchHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6046 import (
        CoaxialConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6047 import (
        ComplianceAndForceData,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6048 import (
        ComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6049 import (
        ConceptCouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6050 import (
        ConceptCouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6051 import (
        ConceptCouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6052 import (
        ConceptGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6053 import (
        ConceptGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6054 import (
        ConceptGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6055 import (
        ConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6056 import (
        ConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6057 import (
        ConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6058 import (
        ConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6059 import (
        ConnectorHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6060 import (
        CouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6061 import (
        CouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6062 import (
        CouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6063 import (
        CVTBeltConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6064 import (
        CVTHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6065 import (
        CVTPulleyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6066 import (
        CycloidalAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6067 import (
        CycloidalDiscCentralBearingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6068 import (
        CycloidalDiscHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6069 import (
        CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6070 import (
        CylindricalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6071 import (
        CylindricalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6072 import (
        CylindricalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6073 import (
        CylindricalPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6074 import (
        DampingSpecification,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6075 import (
        DatumHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6076 import (
        DynamicModelForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6077 import (
        ElectricMachinePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6078 import (
        ElectricMachineRotorXForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6079 import (
        ElectricMachineRotorXMomentPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6080 import (
        ElectricMachineRotorYForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6081 import (
        ElectricMachineRotorYMomentPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6082 import (
        ElectricMachineRotorZForcePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6083 import (
        ElectricMachineStatorToothAxialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6084 import (
        ElectricMachineStatorToothLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6085 import (
        ElectricMachineStatorToothMomentsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6086 import (
        ElectricMachineStatorToothRadialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6087 import (
        ElectricMachineStatorToothTangentialLoadsExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6088 import (
        ElectricMachineTorqueRipplePeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6089 import (
        ExportOutputType,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6090 import (
        ExternalCADModelHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6091 import (
        FaceGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6092 import (
        FaceGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6093 import (
        FaceGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6094 import (
        FEPartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6095 import (
        FlexiblePinAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6096 import (
        FrequencyOptionsForHarmonicAnalysisResults,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6097 import (
        GearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6098 import (
        GearMeshExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6099 import (
        GearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6100 import (
        GearMeshMisalignmentExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6101 import (
        GearMeshTEExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6102 import (
        GearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6103 import (
        GeneralPeriodicExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6104 import (
        GuideDxfModelHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6105 import (
        HarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6106 import (
        HarmonicAnalysisBarModelFEExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6107 import (
        HarmonicAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6108 import (
        HarmonicAnalysisExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6109 import (
        HarmonicAnalysisFEExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6110 import (
        HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6111 import (
        HarmonicAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6112 import (
        HarmonicAnalysisRootAssemblyAndFESharedExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6113 import (
        HarmonicAnalysisRootAssemblyExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6114 import (
        HarmonicAnalysisShaftExportOptions,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6115 import (
        HarmonicAnalysisTorqueInputType,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6116 import (
        HarmonicAnalysisWithVaryingStiffnessStaticLoadCase,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6117 import (
        HypoidGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6118 import (
        HypoidGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6119 import (
        HypoidGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6120 import (
        InterMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6121 import (
        KlingelnbergCycloPalloidConicalGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6122 import (
        KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6123 import (
        KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6124 import (
        KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6125 import (
        KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6126 import (
        KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6127 import (
        KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6128 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6129 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6130 import (
        MassDiscHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6131 import (
        MeasurementComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6132 import (
        MicrophoneArrayHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6133 import (
        MicrophoneHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6134 import (
        ModalCorrectionMethod,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6135 import (
        MountableComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6136 import (
        OilSealHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6137 import (
        PartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6138 import (
        PartToPartShearCouplingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6139 import (
        PartToPartShearCouplingHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6140 import (
        PartToPartShearCouplingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6141 import (
        PeriodicExcitationWithReferenceShaft,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6142 import (
        PlanetaryConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6143 import (
        PlanetaryGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6144 import (
        PlanetCarrierHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6145 import (
        PointLoadHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6146 import (
        PowerLoadHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6147 import (
        PulleyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6148 import (
        ResponseCacheLevel,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6149 import (
        RingPinsHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6150 import (
        RingPinsToDiscConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6151 import (
        RollingRingAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6152 import (
        RollingRingConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6153 import (
        RollingRingHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6154 import (
        RootAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6155 import (
        ShaftHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6156 import (
        ShaftHubConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6157 import (
        ShaftToMountableComponentConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6158 import (
        SingleNodePeriodicExcitationWithReferenceShaft,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6159 import (
        SpecialisedAssemblyHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6160 import (
        SpeedOptionsForHarmonicAnalysisResults,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6161 import (
        SpiralBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6162 import (
        SpiralBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6163 import (
        SpiralBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6164 import (
        SpringDamperConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6165 import (
        SpringDamperHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6166 import (
        SpringDamperHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6167 import (
        StiffnessOptionsForHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6168 import (
        StraightBevelDiffGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6169 import (
        StraightBevelDiffGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6170 import (
        StraightBevelDiffGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6171 import (
        StraightBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6172 import (
        StraightBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6173 import (
        StraightBevelGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6174 import (
        StraightBevelPlanetGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6175 import (
        StraightBevelSunGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6176 import (
        SynchroniserHalfHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6177 import (
        SynchroniserHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6178 import (
        SynchroniserPartHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6179 import (
        SynchroniserSleeveHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6180 import (
        TorqueConverterConnectionHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6181 import (
        TorqueConverterHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6182 import (
        TorqueConverterPumpHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6183 import (
        TorqueConverterTurbineHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6184 import (
        UnbalancedMassExcitationDetail,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6185 import (
        UnbalancedMassHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6186 import (
        VirtualComponentHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6187 import (
        WormGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6188 import (
        WormGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6189 import (
        WormGearSetHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6190 import (
        ZerolBevelGearHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6191 import (
        ZerolBevelGearMeshHarmonicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses._6192 import (
        ZerolBevelGearSetHarmonicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.harmonic_analyses._6021": [
            "AbstractAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6022": [
            "AbstractPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6023": [
            "AbstractShaftHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6024": [
            "AbstractShaftOrHousingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6025": [
            "AbstractShaftToMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6026": [
            "AGMAGleasonConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6027": [
            "AGMAGleasonConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6028": [
            "AGMAGleasonConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6029": [
            "AssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6030": [
            "BearingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6031": [
            "BeltConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6032": [
            "BeltDriveHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6033": [
            "BevelDifferentialGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6034": [
            "BevelDifferentialGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6035": [
            "BevelDifferentialGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6036": [
            "BevelDifferentialPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6037": [
            "BevelDifferentialSunGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6038": [
            "BevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6039": [
            "BevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6040": [
            "BevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6041": [
            "BoltedJointHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6042": [
            "BoltHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6043": [
            "ClutchConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6044": [
            "ClutchHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6045": [
            "ClutchHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6046": [
            "CoaxialConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6047": [
            "ComplianceAndForceData"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6048": [
            "ComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6049": [
            "ConceptCouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6050": [
            "ConceptCouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6051": [
            "ConceptCouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6052": [
            "ConceptGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6053": [
            "ConceptGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6054": [
            "ConceptGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6055": [
            "ConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6056": [
            "ConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6057": [
            "ConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6058": [
            "ConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6059": [
            "ConnectorHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6060": [
            "CouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6061": [
            "CouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6062": [
            "CouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6063": [
            "CVTBeltConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6064": [
            "CVTHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6065": [
            "CVTPulleyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6066": [
            "CycloidalAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6067": [
            "CycloidalDiscCentralBearingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6068": [
            "CycloidalDiscHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6069": [
            "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6070": [
            "CylindricalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6071": [
            "CylindricalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6072": [
            "CylindricalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6073": [
            "CylindricalPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6074": [
            "DampingSpecification"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6075": [
            "DatumHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6076": [
            "DynamicModelForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6077": [
            "ElectricMachinePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6078": [
            "ElectricMachineRotorXForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6079": [
            "ElectricMachineRotorXMomentPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6080": [
            "ElectricMachineRotorYForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6081": [
            "ElectricMachineRotorYMomentPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6082": [
            "ElectricMachineRotorZForcePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6083": [
            "ElectricMachineStatorToothAxialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6084": [
            "ElectricMachineStatorToothLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6085": [
            "ElectricMachineStatorToothMomentsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6086": [
            "ElectricMachineStatorToothRadialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6087": [
            "ElectricMachineStatorToothTangentialLoadsExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6088": [
            "ElectricMachineTorqueRipplePeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6089": [
            "ExportOutputType"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6090": [
            "ExternalCADModelHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6091": [
            "FaceGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6092": [
            "FaceGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6093": [
            "FaceGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6094": [
            "FEPartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6095": [
            "FlexiblePinAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6096": [
            "FrequencyOptionsForHarmonicAnalysisResults"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6097": [
            "GearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6098": [
            "GearMeshExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6099": [
            "GearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6100": [
            "GearMeshMisalignmentExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6101": [
            "GearMeshTEExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6102": [
            "GearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6103": [
            "GeneralPeriodicExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6104": [
            "GuideDxfModelHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6105": [
            "HarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6106": [
            "HarmonicAnalysisBarModelFEExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6107": [
            "HarmonicAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6108": [
            "HarmonicAnalysisExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6109": [
            "HarmonicAnalysisFEExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6110": [
            "HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6111": [
            "HarmonicAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6112": [
            "HarmonicAnalysisRootAssemblyAndFESharedExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6113": [
            "HarmonicAnalysisRootAssemblyExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6114": [
            "HarmonicAnalysisShaftExportOptions"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6115": [
            "HarmonicAnalysisTorqueInputType"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6116": [
            "HarmonicAnalysisWithVaryingStiffnessStaticLoadCase"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6117": [
            "HypoidGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6118": [
            "HypoidGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6119": [
            "HypoidGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6120": [
            "InterMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6121": [
            "KlingelnbergCycloPalloidConicalGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6122": [
            "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6123": [
            "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6124": [
            "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6125": [
            "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6126": [
            "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6127": [
            "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6128": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6129": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6130": [
            "MassDiscHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6131": [
            "MeasurementComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6132": [
            "MicrophoneArrayHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6133": [
            "MicrophoneHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6134": [
            "ModalCorrectionMethod"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6135": [
            "MountableComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6136": [
            "OilSealHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6137": [
            "PartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6138": [
            "PartToPartShearCouplingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6139": [
            "PartToPartShearCouplingHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6140": [
            "PartToPartShearCouplingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6141": [
            "PeriodicExcitationWithReferenceShaft"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6142": [
            "PlanetaryConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6143": [
            "PlanetaryGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6144": [
            "PlanetCarrierHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6145": [
            "PointLoadHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6146": [
            "PowerLoadHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6147": [
            "PulleyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6148": [
            "ResponseCacheLevel"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6149": [
            "RingPinsHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6150": [
            "RingPinsToDiscConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6151": [
            "RollingRingAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6152": [
            "RollingRingConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6153": [
            "RollingRingHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6154": [
            "RootAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6155": [
            "ShaftHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6156": [
            "ShaftHubConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6157": [
            "ShaftToMountableComponentConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6158": [
            "SingleNodePeriodicExcitationWithReferenceShaft"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6159": [
            "SpecialisedAssemblyHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6160": [
            "SpeedOptionsForHarmonicAnalysisResults"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6161": [
            "SpiralBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6162": [
            "SpiralBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6163": [
            "SpiralBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6164": [
            "SpringDamperConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6165": [
            "SpringDamperHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6166": [
            "SpringDamperHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6167": [
            "StiffnessOptionsForHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6168": [
            "StraightBevelDiffGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6169": [
            "StraightBevelDiffGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6170": [
            "StraightBevelDiffGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6171": [
            "StraightBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6172": [
            "StraightBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6173": [
            "StraightBevelGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6174": [
            "StraightBevelPlanetGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6175": [
            "StraightBevelSunGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6176": [
            "SynchroniserHalfHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6177": [
            "SynchroniserHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6178": [
            "SynchroniserPartHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6179": [
            "SynchroniserSleeveHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6180": [
            "TorqueConverterConnectionHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6181": [
            "TorqueConverterHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6182": [
            "TorqueConverterPumpHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6183": [
            "TorqueConverterTurbineHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6184": [
            "UnbalancedMassExcitationDetail"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6185": [
            "UnbalancedMassHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6186": [
            "VirtualComponentHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6187": [
            "WormGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6188": [
            "WormGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6189": [
            "WormGearSetHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6190": [
            "ZerolBevelGearHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6191": [
            "ZerolBevelGearMeshHarmonicAnalysis"
        ],
        "_private.system_model.analyses_and_results.harmonic_analyses._6192": [
            "ZerolBevelGearSetHarmonicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyHarmonicAnalysis",
    "AbstractPeriodicExcitationDetail",
    "AbstractShaftHarmonicAnalysis",
    "AbstractShaftOrHousingHarmonicAnalysis",
    "AbstractShaftToMountableComponentConnectionHarmonicAnalysis",
    "AGMAGleasonConicalGearHarmonicAnalysis",
    "AGMAGleasonConicalGearMeshHarmonicAnalysis",
    "AGMAGleasonConicalGearSetHarmonicAnalysis",
    "AssemblyHarmonicAnalysis",
    "BearingHarmonicAnalysis",
    "BeltConnectionHarmonicAnalysis",
    "BeltDriveHarmonicAnalysis",
    "BevelDifferentialGearHarmonicAnalysis",
    "BevelDifferentialGearMeshHarmonicAnalysis",
    "BevelDifferentialGearSetHarmonicAnalysis",
    "BevelDifferentialPlanetGearHarmonicAnalysis",
    "BevelDifferentialSunGearHarmonicAnalysis",
    "BevelGearHarmonicAnalysis",
    "BevelGearMeshHarmonicAnalysis",
    "BevelGearSetHarmonicAnalysis",
    "BoltedJointHarmonicAnalysis",
    "BoltHarmonicAnalysis",
    "ClutchConnectionHarmonicAnalysis",
    "ClutchHalfHarmonicAnalysis",
    "ClutchHarmonicAnalysis",
    "CoaxialConnectionHarmonicAnalysis",
    "ComplianceAndForceData",
    "ComponentHarmonicAnalysis",
    "ConceptCouplingConnectionHarmonicAnalysis",
    "ConceptCouplingHalfHarmonicAnalysis",
    "ConceptCouplingHarmonicAnalysis",
    "ConceptGearHarmonicAnalysis",
    "ConceptGearMeshHarmonicAnalysis",
    "ConceptGearSetHarmonicAnalysis",
    "ConicalGearHarmonicAnalysis",
    "ConicalGearMeshHarmonicAnalysis",
    "ConicalGearSetHarmonicAnalysis",
    "ConnectionHarmonicAnalysis",
    "ConnectorHarmonicAnalysis",
    "CouplingConnectionHarmonicAnalysis",
    "CouplingHalfHarmonicAnalysis",
    "CouplingHarmonicAnalysis",
    "CVTBeltConnectionHarmonicAnalysis",
    "CVTHarmonicAnalysis",
    "CVTPulleyHarmonicAnalysis",
    "CycloidalAssemblyHarmonicAnalysis",
    "CycloidalDiscCentralBearingConnectionHarmonicAnalysis",
    "CycloidalDiscHarmonicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionHarmonicAnalysis",
    "CylindricalGearHarmonicAnalysis",
    "CylindricalGearMeshHarmonicAnalysis",
    "CylindricalGearSetHarmonicAnalysis",
    "CylindricalPlanetGearHarmonicAnalysis",
    "DampingSpecification",
    "DatumHarmonicAnalysis",
    "DynamicModelForHarmonicAnalysis",
    "ElectricMachinePeriodicExcitationDetail",
    "ElectricMachineRotorXForcePeriodicExcitationDetail",
    "ElectricMachineRotorXMomentPeriodicExcitationDetail",
    "ElectricMachineRotorYForcePeriodicExcitationDetail",
    "ElectricMachineRotorYMomentPeriodicExcitationDetail",
    "ElectricMachineRotorZForcePeriodicExcitationDetail",
    "ElectricMachineStatorToothAxialLoadsExcitationDetail",
    "ElectricMachineStatorToothLoadsExcitationDetail",
    "ElectricMachineStatorToothMomentsExcitationDetail",
    "ElectricMachineStatorToothRadialLoadsExcitationDetail",
    "ElectricMachineStatorToothTangentialLoadsExcitationDetail",
    "ElectricMachineTorqueRipplePeriodicExcitationDetail",
    "ExportOutputType",
    "ExternalCADModelHarmonicAnalysis",
    "FaceGearHarmonicAnalysis",
    "FaceGearMeshHarmonicAnalysis",
    "FaceGearSetHarmonicAnalysis",
    "FEPartHarmonicAnalysis",
    "FlexiblePinAssemblyHarmonicAnalysis",
    "FrequencyOptionsForHarmonicAnalysisResults",
    "GearHarmonicAnalysis",
    "GearMeshExcitationDetail",
    "GearMeshHarmonicAnalysis",
    "GearMeshMisalignmentExcitationDetail",
    "GearMeshTEExcitationDetail",
    "GearSetHarmonicAnalysis",
    "GeneralPeriodicExcitationDetail",
    "GuideDxfModelHarmonicAnalysis",
    "HarmonicAnalysis",
    "HarmonicAnalysisBarModelFEExportOptions",
    "HarmonicAnalysisDrawStyle",
    "HarmonicAnalysisExportOptions",
    "HarmonicAnalysisFEExportOptions",
    "HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation",
    "HarmonicAnalysisOptions",
    "HarmonicAnalysisRootAssemblyAndFESharedExportOptions",
    "HarmonicAnalysisRootAssemblyExportOptions",
    "HarmonicAnalysisShaftExportOptions",
    "HarmonicAnalysisTorqueInputType",
    "HarmonicAnalysisWithVaryingStiffnessStaticLoadCase",
    "HypoidGearHarmonicAnalysis",
    "HypoidGearMeshHarmonicAnalysis",
    "HypoidGearSetHarmonicAnalysis",
    "InterMountableComponentConnectionHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshHarmonicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysis",
    "MassDiscHarmonicAnalysis",
    "MeasurementComponentHarmonicAnalysis",
    "MicrophoneArrayHarmonicAnalysis",
    "MicrophoneHarmonicAnalysis",
    "ModalCorrectionMethod",
    "MountableComponentHarmonicAnalysis",
    "OilSealHarmonicAnalysis",
    "PartHarmonicAnalysis",
    "PartToPartShearCouplingConnectionHarmonicAnalysis",
    "PartToPartShearCouplingHalfHarmonicAnalysis",
    "PartToPartShearCouplingHarmonicAnalysis",
    "PeriodicExcitationWithReferenceShaft",
    "PlanetaryConnectionHarmonicAnalysis",
    "PlanetaryGearSetHarmonicAnalysis",
    "PlanetCarrierHarmonicAnalysis",
    "PointLoadHarmonicAnalysis",
    "PowerLoadHarmonicAnalysis",
    "PulleyHarmonicAnalysis",
    "ResponseCacheLevel",
    "RingPinsHarmonicAnalysis",
    "RingPinsToDiscConnectionHarmonicAnalysis",
    "RollingRingAssemblyHarmonicAnalysis",
    "RollingRingConnectionHarmonicAnalysis",
    "RollingRingHarmonicAnalysis",
    "RootAssemblyHarmonicAnalysis",
    "ShaftHarmonicAnalysis",
    "ShaftHubConnectionHarmonicAnalysis",
    "ShaftToMountableComponentConnectionHarmonicAnalysis",
    "SingleNodePeriodicExcitationWithReferenceShaft",
    "SpecialisedAssemblyHarmonicAnalysis",
    "SpeedOptionsForHarmonicAnalysisResults",
    "SpiralBevelGearHarmonicAnalysis",
    "SpiralBevelGearMeshHarmonicAnalysis",
    "SpiralBevelGearSetHarmonicAnalysis",
    "SpringDamperConnectionHarmonicAnalysis",
    "SpringDamperHalfHarmonicAnalysis",
    "SpringDamperHarmonicAnalysis",
    "StiffnessOptionsForHarmonicAnalysis",
    "StraightBevelDiffGearHarmonicAnalysis",
    "StraightBevelDiffGearMeshHarmonicAnalysis",
    "StraightBevelDiffGearSetHarmonicAnalysis",
    "StraightBevelGearHarmonicAnalysis",
    "StraightBevelGearMeshHarmonicAnalysis",
    "StraightBevelGearSetHarmonicAnalysis",
    "StraightBevelPlanetGearHarmonicAnalysis",
    "StraightBevelSunGearHarmonicAnalysis",
    "SynchroniserHalfHarmonicAnalysis",
    "SynchroniserHarmonicAnalysis",
    "SynchroniserPartHarmonicAnalysis",
    "SynchroniserSleeveHarmonicAnalysis",
    "TorqueConverterConnectionHarmonicAnalysis",
    "TorqueConverterHarmonicAnalysis",
    "TorqueConverterPumpHarmonicAnalysis",
    "TorqueConverterTurbineHarmonicAnalysis",
    "UnbalancedMassExcitationDetail",
    "UnbalancedMassHarmonicAnalysis",
    "VirtualComponentHarmonicAnalysis",
    "WormGearHarmonicAnalysis",
    "WormGearMeshHarmonicAnalysis",
    "WormGearSetHarmonicAnalysis",
    "ZerolBevelGearHarmonicAnalysis",
    "ZerolBevelGearMeshHarmonicAnalysis",
    "ZerolBevelGearSetHarmonicAnalysis",
)
